@@ -356,6 +356,9 @@ void Qhelp(void)
     "  the results much -- an important issue for statistical analysis of the\n"
     "  EPI time series.\n"
     "\n"
+    "  Various functions, such as volume change fraction (Jacobian determinant)\n"
+    "  can be calculated from the warp dataset via program 3dNwarpFuncs.\n"
+    "\n"
     "-------\n"
     "OPTIONS\n"
     "-------\n"
@@ -404,7 +407,7 @@ void Qhelp(void)
     "   *OR*         the source dataset to the base with an affine transformation.\n"
     " -allin         It will then use that alignment as a starting point for the\n"
     "                nonlinear warping.\n"
-    "               * With -allineate, the source dataset does not have to be on\n"
+    "               * With -allineate, the source dataset does NOT have to be on\n"
     "                 the same 3D grid as the base, since the intermediate output\n"
     "                 of 3dAllineate (the substitute source) will be on the grid\n"
     "                 as the base.\n"
@@ -419,8 +422,9 @@ void Qhelp(void)
     "          -->>** The final output warped dataset is warped directly from the\n"
     "                 original source dataset, NOT from the substitute source.\n"
     "               * The intermediate files from 3dAllineate (the substitute source\n"
-    "                 dataset and the affine matrix) are deleted from disk after\n"
-    "                 being read into 3dQwarp.\n"
+    "                 dataset and the affine matrix) are saved, using 'prefix_Allin'\n"
+    "                 in the filenames.  If you wish to have them deleted, use the\n"
+    "                 option '-allinkill' in addition to '-allineate'.\n"
     "             *** The following 3dQwarp options CANNOT be used with -allineate:\n"
     "                   -plusminus  -inilev  -iniwarp\n"
     "             *** However, you CAN use -duplo with -allineate.\n"
@@ -430,8 +434,12 @@ void Qhelp(void)
     " -allopt         command to be run by 3dQwarp.  Normally, you won't need\n"
     "                 to do this.\n"
     "               * All the extra options for the 3dAllineate command line\n"
-    "                 should be enclosed inside a pair of quote marks.\n"
-    "              ** Do NOT attempt to use the (obsolescent) '-nwarp' option in\n"
+    "                 should be enclosed inside a pair of quote marks; e.g.,\n"
+    "                    -allopt '-cost lpa -verb'\n"
+    "               * If '-emask' is used in 3dQwarp, the same option will be\n"
+    "                 passed to 3dAllineate automatically, so you don't have to\n"
+    "                 do that yourself.\n"
+    "             *** Do NOT attempt to use the (obsolescent) '-nwarp' option in\n"
     "                 3dAllineate from inside 3dQwarp -- bad things will probably\n"
     "                 happen, and you won't EVER get any Christmas presents again!\n"
     "\n"
@@ -717,7 +725,7 @@ void Qhelp(void)
     "\n"
     "The penalty is a Neo-Hookean elastic energy function, based on a combination\n"
     "of bulk and shear distortions; cf. http://en.wikipedia.org/wiki/Neo-Hookean_solid\n"
-    "The goal is to keep the warps from becoming too 'weird'.\n"
+    "The goal is to keep the warps from becoming too 'weird' (not that this always works).\n"
     "\n"
     "***** This program is experimental and subject to sudden horrific change! *****\n"
     "\n"
@@ -809,12 +817,12 @@ int main( int argc , char *argv[] )
    char *bsname=NULL , *iwname=NULL , *ssname=NULL , *esname=NULL ;
    MRI_IMAGE *bim , *wbim , *sim , *oim ; float bmin,smin ;
    IndexWarp3D *oww , *owwi ; Image_plus_Warp *oiw=NULL ;
-   char *prefix = "Qwarp" ; int nopt , nevox=0 ;
+   char *prefix="Qwarp" , *prefix_clean=NULL ; int nopt , nevox=0 ;
    int meth = GA_MATCH_PEARCLP_SCALAR ;
    int ilev = 0 , nowarp = 0 , nowarpi = 1 , mlev = 666 , nodset = 0 ;
    int duplo=0 , qsave=0 , minpatch=0 , nx,ny,nz , ct , nnn , noneg = 0 ;
    int do_allin=0 ; char *allopt=NULL ; mat44 allin_matrix ;
-   int do_resam=0 ;
+   int do_resam=0 ; int keep_allin=1 ;
    int flags = 0 , nbad = 0 ;
    double cput = 0.0 ;
    int do_plusminus=0; Image_plus_Warp **sbww=NULL, *qiw=NULL; /* 14 May 2013 */
@@ -854,8 +862,10 @@ int main( int argc , char *argv[] )
    (void)COX_clock_time() ;  /* initialize the clock timer */
    putenv("AFNI_WSINC5_SILENT=YES") ;
 
+   LOAD_IDENT_MAT44(allin_matrix); /* Just to quite initialization warning */
+   
    /*--- options ---*/
-
+   
    nopt = 1 ;
    Hblur_b = Hblur_s = 2.345f ;
    while( nopt < argc && argv[nopt][0] == '-' ){
@@ -884,6 +894,13 @@ int main( int argc , char *argv[] )
        do_allin =  1 ; nopt++ ; continue ;
      }
 
+     if( strcasecmp(argv[nopt],"-allinkeep") == 0 ){       /* 27 Aug 2013 */
+       keep_allin = 1 ; nopt++ ; continue ;
+     }
+     if( strcasecmp(argv[nopt],"-allinkill") == 0 ){       /* 27 Aug 2013 */
+       keep_allin = 0 ; nopt++ ; continue ;
+     }
+
      if( strcasecmp(argv[nopt],"-allinfast") == 0 ||       /* 19 Jul 2013 */
          strcasecmp(argv[nopt],"-allfast"  ) == 0   ){
        do_allin =  2 ; nopt++ ; continue ;
@@ -1110,6 +1127,15 @@ int main( int argc , char *argv[] )
      ERROR_exit("Totally bogus option '%s'",argv[nopt]) ;
    }
 
+   /*-- make a 'clean' prefix --*/
+
+   { char *ns ;
+     prefix_clean = strdup(prefix) ;
+     ns = strstr(prefix_clean,".nii" ) ; if( ns != NULL ) *ns = '\0' ;
+     ns = strstr(prefix_clean,"+orig") ; if( ns != NULL ) *ns = '\0' ;
+     ns = strstr(prefix_clean,"+tlrc") ; if( ns != NULL ) *ns = '\0' ;
+   }
+
    /*----- check for errorororors -----*/
 
 STATUS("check for errors") ;
@@ -1196,7 +1222,7 @@ STATUS("source dataset opened") ;
    }
 
    if( do_allin || do_resam ){
-     char *qs ;  /* temp stuff */
+     char *qs , *ns , *rs ;  /* temp stuff */
 
 STATUS("3dAllineate coming up next") ;
 
@@ -1220,13 +1246,19 @@ STATUS("3dAllineate coming up next") ;
 
      fprintf(stderr,"\n") ;
 
-     INFO_message("3dQwarp: replacing source dataset with %s.nii",Qunstr) ;
-     qs = (char *)malloc(strlen(Qunstr)+64) ;
+     qs = (char *)malloc(strlen(Qunstr)+strlen(prefix)+64) ;
+     ns = (char *)malloc(strlen(Qunstr)+strlen(prefix)+64) ;
      sprintf(qs,"%s.nii",Qunstr) ;
-     sset = THD_open_dataset(qs) ;                 /* get its output dataset */
+     if( keep_allin ){
+       sprintf(ns,"%s_Allin.nii",prefix_clean) ; rename(qs,ns) ; rs = ns ;
+     } else {
+       rs = qs ;
+     }
+     INFO_message("3dQwarp: replacing source dataset with %s",rs) ;
+     sset = THD_open_dataset(rs) ;                 /* get its output dataset */
      if( sset == NULL ) ERROR_exit("Can't open replacement source??") ;
      DSET_load(sset) ; CHECK_LOAD_ERROR(sset) ; DSET_lock(sset) ;
-     remove(qs) ;                 /* erase the 3dAllineate dataset from disk */
+     if( !keep_allin ) remove(qs) ;  /* erase the 3dAllineate dataset from disk */
 
      if( do_allin ){
        MRI_IMAGE *qim ; float *qar ;
@@ -1240,13 +1272,18 @@ STATUS("3dAllineate coming up next") ;
        LOAD_MAT44(allin_matrix,qar[0],qar[1],qar[ 2],qar[ 3],
                                qar[4],qar[5],qar[ 6],qar[ 7],
                                qar[8],qar[9],qar[10],qar[11] ) ;
-       remove(qs) ;           /* erase the 3dAllineate matrix file from disk */
-       if( Hverb ) ININFO_message("3dAllineate output files have been deleted");
+       if( !keep_allin ){
+         remove(qs) ;           /* erase the 3dAllineate matrix file from disk */
+         if( Hverb ) ININFO_message("3dAllineate output files have been deleted");
+       } else {
+         sprintf(ns,"%s_Allin.aff12.1D",prefix_clean) ; rename(qs,ns) ;
+         if( Hverb ) ININFO_message("3dAllineate output files have been renamed") ;
+       }
        if( Hverb && do_allin ) DUMP_MAT44("3dAllineate matrix",allin_matrix) ;
        mri_free(qim) ;
      }
 
-     free(qs) ; /* temp string is history */
+     free(qs) ; free(ns) ;
 
    } /*--- end of 3dAllineate prolegomenon ----------------------------------*/
 
