@@ -495,8 +495,6 @@ int main( int argc , char *argv[] )
 
    /*-------------------------- help me if you can? --------------------------*/
 
-
-
    /*-- 20 Apr 2001: addto the arglist, if user wants to [RWCox] --*/
 
    mainENTRY("3drefit main"); machdep() ; PRINT_VERSION("3drefit") ; AUTHOR("RW Cox") ;
@@ -507,6 +505,7 @@ int main( int argc , char *argv[] )
    }
 
    AFNI_logger("3drefit",argc,argv) ;
+   AFNI_setenv("AFNI_COMPRESSOR=NONE") ; /* 26 Jul 2013 */
 
    iarg = 1 ;
    while( iarg < argc && argv[iarg][0] == '-' ){
@@ -1898,7 +1897,11 @@ int main( int argc , char *argv[] )
             dset->view_type = old_vtype ;
             THD_init_diskptr_names( dset->dblk->diskptr ,
                                     NULL , NULL , NULL , old_vtype , True ) ;
-            ERROR_message("Can't change view: would overwrite existing files!\n") ;
+            /* if not changing the current file, fail
+               (i.e. accept in case of NIfTI or similar in -space)
+               (suggested by I Schwabacher)         24 Apr 2013 [rickr] */
+            if( strcmp(old_head, new_head) )
+             ERROR_exit("Can't change view: would overwrite existing files!\n");
          } else {
             rename( old_head , new_head ) ;
             { char * fff = COMPRESS_filename(old_brik) ;
