@@ -434,8 +434,7 @@ SUMA_SegmentDO *SUMA_ControlCurve2SDO(SUMA_MX_VEC *ControlCurve, char *Label)
                                Label, idcode_str, Parent_idcode_str,
                                type_not_set, NULL, LineWidth, LineCol,
                                NodeId, NULL, n0, n1,
-                               colv, thickv 
-                              );
+                               colv, thickv);
 
    if (idcode_str) SUMA_free(idcode_str); idcode_str = NULL;
    if (n0) SUMA_free(n0); n0 = NULL;
