@@ -201,6 +201,7 @@ static mday holiday[] = {
    {JAN,17,"James Earl Jones' birthday"                              } ,
    {JAN,17,"Latvia's Zirgu Diena"                                    } ,
    {JAN,18,"Cary Grants' birthday"                                   } ,
+   {JAN,18,"Saint Malgorzata's (of Hungary) Day"                     } ,
    {JAN,18,"Daniel Webster's birthday"                               } ,
    {JAN,19,"Edgar Allen Poe's birthday"                              } ,
    {JAN,20,"Anniversary of end of American Revolution"               } ,
@@ -255,6 +256,7 @@ static mday holiday[] = {
    {FEB,21,"Anniversary of start of the Battle of Verdun"            } ,
    {FEB,22,"George Washington's birthday"                            } ,
    {FEB,22,"Frederic Chopin's birthday"                              } ,
+   {FEB,22,"Saint Malgorzata's (of Cortona) Day"                     } ,
    {FEB,24,"St. Ethelbert's day"                                     } ,
    {FEB,25,"Auguste Renoir's birthday"                               } ,
    {FEB,27,"Dominican Republic Independence Day"                     } ,
@@ -476,6 +478,7 @@ static mday holiday[] = {
    {JUL,19,"George McGovern's birthday"                              } ,
    {JUL,19,"Edgar Degas' birthday"                                   } ,
    {JUL,20,"Anniversary of Apollo 11 Moon landing"                   } ,
+   {JUL,20,"Saint Malgorzata's (of Antioch) Day"                     } ,
    {JUL,20,"Sir Edmund Hillary's birthday"                           } ,
    {JUL,20,"Columbia Independence Day"                               } ,
    {JUL,21,"Belgium Independence Day"                                } ,
@@ -666,6 +669,7 @@ static mday holiday[] = {
    {NOV,14,"Claude Monet's birthday"                                 } ,
    {NOV,16,"James Bonds' birthday"                                   } ,
    {NOV,16,"d'Alembert's birthday"                                   } ,
+   {NOV,16,"Saint Malgorzata's (of Scotland) Day"                    } ,
    {NOV,17,"Korbinian Brodmann's birthday"                           } ,
    {NOV,18,"Ignacy Paderewski's birthday"                            } ,
    {NOV,19,"Anniversary of Gettysburg Address"                       } ,
