@@ -271,7 +271,7 @@ extern long   strtol() ;
 # define DONT_USE_MATRIX_MAT  /* 04 Mar 2005 */
 # undef  DONT_USE_HTMLWIN     /* 08 Jul 2011 */
 # define UNFONTIZE_HTMLWIN    /* 08 Jul 2011 */
-# define strcasestr SOLARIS_strcasestr 
+# define strcasestr AFNI_strcasestr 
 
 
 #ifdef SOLARIS_OLD            /* 03 Feb 2009 [rickr] */
@@ -426,7 +426,7 @@ extern void init_rand_seed( long int seed ) ; /* 15 Apr 2009 (cf machdep.c) */
 extern int machdep_be_quiet(void) ;  /* 08 Dec 2010 */
 extern char * GetAfniWebBrowser(void);
 extern char * GetAfniTextEditor(void);
-extern char *SOLARIS_strcasestr(const char *s1, const char *s2);
+extern char * AFNI_strcasestr(const char *s1, const char *s2);
 
 extern void AFNI_do_nothing(void) ;
 
