@@ -73,10 +73,6 @@ def niwrite(data,affine, name , header=None):
 	outni = nib.Nifti1Image(data,affine,header=thishead)
 	outni.to_filename(name)
 	print 'done.'
-	
-	
-
-
 
 def cat2echos(data,Ne):
 	"""
@@ -91,20 +87,22 @@ def cat2echos(data,Ne):
 		nt = data.shape[3]
 	else:
 		nt = 1
-
 	return np.reshape(data,(nx,ny,nz,Ne,nt),order='F')
 
-"""
-def cat2echos(data,Ne):
-	"
-	Input:
-	data shape is nx,ny,nz*ne,nt
+def uncat2echos(data,Ne):
+	"""
+	uncat2echos(data,Ne)
 
-	Output:
-	data shape is nx,ny,nz,ne,nt 
-	"
-	return np.concatenate([data[:,:,ii*nz:(ii+1)*nz-1,np.newaxis,:] for ii in range(Ne)],axis=3)
-"""
+	Input:
+	data shape is (nx,ny,Ne,nz,nt)
+	"""
+    	nx,ny = data.shape[0:2]
+	nz = data.shape[2]*Ne
+	if len(data.shape) >4:
+		nt = data.shape[4]
+	else:
+		nt = 1
+	return np.reshape(data,(nx,ny,nz,nt),order='F')
 
 def makemask(cdat):
 
@@ -197,14 +195,14 @@ def t2smap(catd,mask,tes):
 	t2s = 1/beta[1,:].transpose()
 	s0  = np.exp(beta[0,:]).transpose()
 
-	out = unmask(t2s,mask)
+	out = unmask(t2s,mask),unmask(s0,mask)
 
 	return out
 
 	head.set_data_shape((nx,ny,nz,2))
 	vecwrite(out,'t2s.nii',aff)
 
-def get_coeffs(data,mask,X):
+def get_coeffs(data,mask,X,add_const=False):
 	"""
 	get_coeffs(data,X)
 
@@ -219,36 +217,49 @@ def get_coeffs(data,mask,X):
 	out  has shape (nx,ny,nz,nc)
 	""" 
 	mdata = fmask(data,mask).transpose()
+        
+        X=np.atleast_2d(X)
+        if X.shape[0]==1: X=X.T
+        Xones = np.atleast_2d(np.ones(np.min(mdata.shape))).T
+        if add_const: X = np.hstack([X,Xones])
+
 	tmpbetas = np.linalg.lstsq(X,mdata)[0].transpose()
+        if add_const: tmpbetas = tmpbetas[:,:-1]
 	out = unmask(tmpbetas,mask)
 
 	return out
 
 
+def andb(arrs):
+	result = np.zeros(arrs[0].shape)
+	for aa in arrs: result+=np.array(aa,dtype=np.int)
+	return result
+
 def fitmodels(betas,t2s,mu,mask,tes,cc=-1,sig=None,fout=None,pow=2.):
 	"""
-	Usage:
-
-	fitmodels(betas,t2s,mu,mask,tes)
-
-	Input:
-	betas,mu,mask are all (nx,ny,nz,Ne,nc) ndarrays
-	t2s is a (nx,ny,nz) ndarray
-	tes is a 1d array
-	"""
+   	Usage:
+   	
+   	fitmodels(betas,t2s,mu,mask,tes)
+	
+   	Input:
+   	betas,mu,mask are all (nx,ny,nz,Ne,nc) ndarrays
+   	t2s is a (nx,ny,nz) ndarray
+   	tes is a 1d array
+   	"""
 	fouts  = []
 	nx,ny,nz,Ne,nc = betas.shape
 	Nm = mask.sum()
-
+	
 	tes = np.reshape(tes,(Ne,1))
 	mumask   = fmask(mu,mask)
 	t2smask  = fmask(t2s,mask)
 	betamask = fmask(betas,mask)
-
+	
 	comptab = np.zeros((nc,3))
-
+	
 	#Compute variacnes
 	betasm = fmask(betas,mask)
+	if betas.shape[-1]==1: betasm = np.atleast_3d(betasm)
 	betasm = betasm.reshape([np.prod(betasm.shape[0:2]),betasm.shape[2]])
 	#Compute postive variance
 	betasms = betasm.copy()
@@ -264,42 +275,48 @@ def fitmodels(betas,t2s,mu,mask,tes,cc=-1,sig=None,fout=None,pow=2.):
 	varlist = np.vstack([posvars,negvars])
 	varlist/=np.sum(varlist)
 	varlist = varlist.T
-
+	
+	#import ipdb
+	#ipdb.set_trace()
+	
 	#Setup Xmats
-
+	
 	#Model 1
 	X1 = mumask.transpose()
-
+	
 	#Model 2
 	X2 = np.tile(tes,(1,Nm))*mumask.transpose()/t2smask.transpose()
-
+	
 	if cc!=-1: comps=[cc]
 	else: comps=range(nc)
 	
 	if sig!=None: sigmask=fmask(sig,mask).transpose()
 	
 	for i in comps:
-
+		
 		#size of B is (nc, nx*ny*nz)
-		B = betamask[:,:,i].transpose()
+		B = np.atleast_3d(betamask)[:,:,i].transpose()
 		alpha = (np.abs(B)**2).sum(axis=0)
-
+		
 		#S0 Model
 		coeffs_S0 = (B*X1).sum(axis=0)/(X1**2).sum(axis=0)
 		SSE_S0 = (B - X1*np.tile(coeffs_S0,(Ne,1)))**2
 		SSE_S0 = SSE_S0.sum(axis=0)
-
+		
 		F_S0 = (alpha - SSE_S0)*2/(SSE_S0)
 		#F_S0 = (SSTR_S0)*2/(alpha - SSTR_S0)
-
+		
 		#R2 Model
 		coeffs_R2 = (B*X2).sum(axis=0)/(X2**2).sum(axis=0)
 		SSE_R2 = (B - X2*np.tile(coeffs_R2,(Ne,1)))**2
 		SSE_R2 = SSE_R2.sum(axis=0)
 		F_R2 = (alpha - SSE_R2)*2/(SSE_R2)
-
+		
+		#ipdb.set_trace()
+		
 		Bn = B/sigmask
-		Bz=(Bn-np.tile(Bn.mean(axis=-1),(Bn.shape[1],1)).T)/np.tile(Bn.std(axis=-1),(Bn.shape[1],1)).T
+		#Bz=(Bn-np.tile(Bn.mean(axis=-1),(Bn.shape[1],1)).T)/np.tile(Bn.std(axis=-1),(Bn.shape[1],1)).T
+		Bz=Bn/np.tile(Bn.std(axis=-1),(Bn.shape[1],1)).T
 		wts = Bz.mean(axis=0)*sfacs[i]
 		
 		
@@ -312,12 +329,12 @@ def fitmodels(betas,t2s,mu,mask,tes,cc=-1,sig=None,fout=None,pow=2.):
 		
 		kappa = np.average(F_R2,weights = wts)
 		rho   = np.average(F_S0,weights = wts)		
-
+		
 		print "Comp %d Kappa: %f Rho %f" %(i,kappa,rho)
 		comptab[i,0] = i
 		comptab[i,1] = kappa
 		comptab[i,2] = rho
-
+		
 		# Output Voxelwise F-Stats. "fout" is the affine transformation
 		if fout is not None:
 			
@@ -329,94 +346,34 @@ def fitmodels(betas,t2s,mu,mask,tes,cc=-1,sig=None,fout=None,pow=2.):
 			out[:,:,:,0] = np.squeeze(unmask(Bpsc,mask))*sfacs[i]
 			out[:,:,:,1] = np.squeeze(unmask(F_R2,mask))
 			out[:,:,:,2] = np.squeeze(unmask(F_S0,mask))
-
+			
 			niwrite(out,fout,name)
 			os.system('3drefit -sublabel 0 PSC -sublabel 1 F_R2  -sublabel 2 F_SO %s 2> /dev/null > /dev/null'%name)
-
+		
 		#debug
 		if cc!=-1: return [F_R2,alpha]
-		
+	
 	comptab = np.hstack([comptab,varlist])
 	return comptab
 
-def andb(arrs):
-	result = np.zeros(arrs[0].shape)
-	for aa in arrs: result+=np.array(aa,dtype=np.int)
-	return result
-
-	
-def selcomps(comptable,hifm=True):
-
+def selcomps(comptable):
 	fmin,fmid,fmax = getfbounds(ne)
-	ctb = comptable[comptable[:,1].argsort()[::-1],:]
-
-	accvprez = ctb[ctb[:,1]>100,3:5].sum(axis=1)
-	accvprez = (accvprez-accvprez.mean())/accvprez.std()
-	accrprez = ctb[ctb[:,1]>100,2]
-	accrprez = (accrprez-accrprez.mean())/accrprez.std()
-	accspre = np.array(accvprez+accrprez>3,dtype=np.int)+np.array(ctb[ctb[:,1]>100,3:5].sum(axis=1)>5,dtype=np.int)
-	
-	print accvprez,accrprez
-
-	acc = list(ctb[ctb[:,1]>100,0][accspre<2])
-	rej = list(ctb[ctb[:,2]>fmid,0])
-	mid = list(set(range(ctb.shape[0]))-set(acc)-set(rej))
-	
-	if len(acc) <= 15 and ctb[1,1]<150: lowq=1
-	else: lowq=0
-		
-	ctbm = comptable[mid]
-	ctbm = ctbm[ctbm[:,1].argsort()[::-1],:]
-	rej+=list(ctbm[getelbow(ctbm[:,1])-1:,0])
-	mid=list(ctbm[:getelbow(ctbm[:,1])-1,0])
-
-	betasm = fmask(betas,mask)
-	vars = (betasm.reshape(np.prod(betasm.shape[0:2]),betasm.shape[2])**2).sum(0)
-	varpers  = vars/vars.sum()
-	midvarthr = vars[acc].mean()
-	if lowq==0: midrhothr = comptable[acc,2].mean()+3*comptable[acc,2].std()
-	if lowq==1: midrhothr = min(comptable[:,2].mean(),fmid,comptable[getelbow(comptable[:,2][::-1])-1,1])
-
-	#import ipdb
+	ctb = comptable[ comptable[:,1].argsort()[::-1],:]
+	ks = ctb[:,1]
+	rs =ctb[ ctb[:,2].argsort()[::-1],2]
+	k_t = ks[getelbow(ks)+1]
+	r_t = rs[getelbow(rs)+1]
+	sel = andb([ctb[:,1]>=k_t, ctb[:,2]<r_t])
+	acc = ctb[sel==2,0]
+	rej = ctb[sel!=2,0]
+	mid = np.array([])
 	#ipdb.set_trace()
+	#(ctb[sel==2,1]).argsort().argsort()-(ctb[sel==2,3:5].sum(axis=1)*100).argsort().argsort()
+	open('accepted.txt','w').write(','.join([str(int(cc)) for cc in acc]))
+	open('rejected.txt','w').write(','.join([str(int(cc)) for cc in rej]))
+	open('midk_rejected.txt','w').write(','.join([str(int(cc)) for cc in mid]))
+	return acc.tolist(),rej.tolist(),mid.tolist()
 
-	addacc = np.array(mid)[andb([comptable[mid,2]<midrhothr,vars[mid]<midvarthr])==2]
-	if len(addacc)!=0: acc+=list(addacc)
-	mid = list(set(range(ctb.shape[0]))-set(acc)-set(rej))
-	
-	np.savetxt('accepted.txt',acc,fmt='%d',delimiter=',')
-	np.savetxt('rejected.txt',rej,fmt='%d',delimiter=',')
-	np.savetxt('midk_rejected.txt',mid,fmt='%d',delimiter=',')
-	
-	return acc,rej,mid
-	
-
-def dvars(dv,mud):
-	nx,ny,nz,nt = dv.shape
-	d = dv.reshape([nx*ny*nz,nt]).T
-
-	#Compute mean and mask
-	if len(mud.shape) == 4:  
-		mud = mud.reshape([nx*ny*nz,nt]).T
-		d_mu = mud.mean(0).reshape([nx*ny*nz])
-	elif len(mud.shape) ==3 :  d_mu = mud.reshape([nx*ny*nz]) 
-	else: print "Can't figure out mean dataset dimensions. Goodbye."
-	d_beta = d
-	
-	d_mask = d_mu!=0
-	d_mask = (d_mu > scoreatpercentile(d_mu[d_mask],3)) & (d_mu < scoreatpercentile(d_mu[d_mask],98) )
-	dp =   (d_beta[:,d_mask]/d_mu[d_mask])*100
-	dpdt = np.abs(dp[1:]-dp[0:-1])+0.0000001
-
-	#Condition distribution of dp/dt's
-	dpdt_thr = np.log10(dpdt).mean(0)
-	dpdt_max = pow(10,scoreatpercentile(dpdt_thr,98))
-	dpdt_mask = dpdt.mean(0) < dpdt_max
-	 
-	#Threshold differentials with extreme values, compute DVARS
-	return np.sqrt(np.mean(dpdt[:,dpdt_mask]**2,1))
-
-	
 def optcom(data,t2s,tes,mask):
 	"""
 	out = optcom(data,t2s)
@@ -478,7 +435,6 @@ def eimask(dd,ees=None):
 		imask[dd[:,ee,:].mean(1) > hthr,ee]=0
 	return imask
 
-
 def tedpca(ste=0):
 	nx,ny,nz,ne,nt = catd.shape
 	ste = np.array([int(ee) for ee in str(ste).split(',')])
@@ -505,14 +461,6 @@ def tedpca(ste=0):
 	
 	##Do PC dimension selection
 	#Get eigenvalue cutoff
-	
-	#print 'Saving for MATLAB'
-	#import scipy.io
-	#scipy.io.savemat('dz.mat',{'dz':dz})
-	
-	#import ipdb
-	#ipdb.set_trace()
-	
 	u,s,v = np.linalg.svd(dz,full_matrices=0)
 	sp = s/s.sum()
 	eigelb = sp[getelbow(sp)]
@@ -533,7 +481,6 @@ def tedpca(ste=0):
 	eimum = np.array(np.squeeze(unmask(np.array(eim,dtype=np.int).prod(1),mask)),dtype=np.bool)
 	betasv = get_coeffs(catim.get_data()-catim.get_data().mean(-1)[:,:,:,np.newaxis],np.tile(eimum,(1,1,Ne)),v.T)
 	betasv = cat2echos(betasv,Ne)
-	
 	ctb = fitmodels(betasv,t2s,mu,eimum,tes,sig=sig,fout=None,pow=2)
 	ctb = np.vstack([ctb.T[0:3],sp]).T
 	
@@ -554,8 +501,6 @@ def tedpca(ste=0):
 	if int(kdaw)!=-1 and int(rdaw)==-1:
 		rhos_lim = rhos[andb([rhos<fmid,rhos>fmin])==2]
 		rho_thr = rhos_lim[getelbow(rhos_lim)]
-	#import ipdb
-	#ipdb.set_trace()
 	if options.stabilize:
 		pcscore = (np.array(ctb[:,1]>kappa_thr,dtype=np.int)+np.array(ctb[:,2]>rho_thr,dtype=np.int)+np.array(ctb[:,3]>eigelb,dtype=np.int))*np.array(ctb[:,3]>spmin,dtype=np.int)*np.array(spcum<0.95,dtype=np.int)*np.array(ctb[:,2]>fmin,dtype=np.int)*np.array(ctb[:,1]>fmin,dtype=np.int)*np.array(ctb[:,1]!=F_MAX,dtype=np.int)*np.array(ctb[:,2]!=F_MAX,dtype=np.int) 
 	else:
@@ -614,7 +559,6 @@ def tedica(dd,cost):
 def write_split_ts(data,comptable,mmix,suffix=''):
 	mdata = fmask(data,mask)
 	betas = fmask(get_coeffs(unmask((mdata.T-mdata.T.mean(0)).T,mask),mask,mmix),mask)
-	acc,rej,midk = selcomps(comptable)
 	niwrite(unmask(betas[:,acc].dot(mmix.T[acc,:]),mask),aff,'_'.join(['hik_ts',suffix])+'.nii')
 	if len(midk)!=0: niwrite(unmask(betas[:,midk].dot(mmix.T[midk,:]),mask),aff,'_'.join(['midk_ts',suffix])+'.nii')
 	niwrite(unmask(betas[:,rej].dot(mmix.T[rej,:]),mask),aff,'_'.join(['lowk_ts',suffix])+'.nii')
@@ -622,14 +566,12 @@ def write_split_ts(data,comptable,mmix,suffix=''):
 
 def split_ts(data,comptable,mmix):
 	cbetas = get_coeffs(data-data.mean(-1)[:,:,:,np.newaxis],mask,mmix)
-	acc,rej,midk = selcomps(comptable)
 	betas = fmask(cbetas,mask)
 	hikts=unmask(betas[:,acc].dot(mmix.T[acc,:]),mask)
 	return hikts,data-hikts
 
 def writefeats(cbetas,comptable,mmix,suffix=''):
 	#Write signal changes (dS)
-	acc,rej,midk = selcomps(comptable)
 	niwrite(cbetas[:,:,:,:],aff,'_'.join(['betas',suffix])+'.nii')
 	niwrite(cbetas[:,:,:,acc],aff,'_'.join(['betas_hik',suffix])+'.nii')
 	#Compute features (dS/S)
@@ -648,22 +590,8 @@ def writefeats(cbetas,comptable,mmix,suffix=''):
 	cbetam = cbetam/fmask(zfac,mask)[:,np.newaxis]
 	cbetam[edm.mean(-1)<1,:] = 0
 	
-	#Compute positive variance
-	#cbetams = cbetam.copy()
-	#cbetams[cbetams<0] = 0
-	#posvars = (cbetams**2).sum(0)
-	#Compute positive variance
-	#cbetams = cbetam.copy()
-	#cbetams[cbetams>0] = 0
-	#negvars = (cbetams**2).sum(0)	
-	
-	#sfacs = np.ones(posvars.shape)
-	#sfacs[negvars>posvars]*=-1
-	#cbetam*=sfacs
-	
 	niwrite(unmask(cbetam,mask),aff,'_'.join(['feats',suffix])+'.nii')
 	
-
 def writect(comptable,ctname=''):
 	nc = comptable.shape[0]
 	sortab = comptable[comptable[:,1].argsort()[::-1],:]
@@ -672,14 +600,6 @@ def writect(comptable,ctname=''):
 		f.write("#	comp	Kappa	Rho	+Var%	-Var%\n")
 		for i in range(nc):
 			f.write('%d\t%f\t%f\t%.2f\t%.2f\n'%(sortab[i,0]+1,sortab[i,1],sortab[i,2],sortab[i,3]*100,sortab[i,4]*100))
-	
-def writemcct(ct,costnames):
-	nc = ct.shape[0]
-	ctname = 'comp_table_multicost.txt'
-	with open(ctname,'w') as f:
-		f.write("#"+'\t'.join(costnames)+"\n")
-		for i in range(nc):
-			f.write('\t'.join(["%.02f" % ct[i,cc] for cc in range(ct.shape[1])])+"\n")
 
 	
 ###################################################################################################
@@ -692,18 +612,15 @@ if __name__=='__main__':
 	parser.add_option('-d',"--orig_data",dest='data',help="Spatially Concatenated Multi-Echo Dataset",default=None)
 	parser.add_option('-e',"--TEs",dest='tes',help="Echo times (in ms) ex: 15,39,63",default=None)
 	parser.add_option('',"--mix",dest='mixm',help="Mixing matrix. If not provided, ME-PCA & ME-ICA (MDP) is done.",default=None)
+	parser.add_option('',"--dmix",dest='dmix',help="Design matrix to test for TE-dep. after denoising (serial/greedy simple regression)",default='')
 	parser.add_option('',"--sourceTEs",dest='ste',help="Source TEs for models. ex: -ste 2,3 ; -ste 0 for all, -1 for opt. com. Default 0.",default=0)	
 	parser.add_option('',"--denoiseTE",dest='e2d',help="TE to denoise. Default middle",default=None)	
-	parser.add_option('',"--repave",dest='repave',help="Repeat ME-ICA n times and average hi K time series.",default=1)
-	parser.add_option('',"--multicost",dest='multicost',help="Repeat ME-ICA with mult. initial costs and average. ex: --multicost pow3,gaus,skew",default="")
 	parser.add_option('',"--initcost",dest='initcost',help="Initial cost func. for ICA: pow3,tanh(default),gaus,skew",default='tanh')
 	parser.add_option('',"--finalcost",dest='finalcost',help="Final cost func, same opts. as initial",default='tanh')	
 	parser.add_option('',"--stabilize",dest='stabilize',action='store_true',help="Stabilize convergence by reducing dimensionality, for low quality data",default=False)	
 	parser.add_option('',"--conv",dest='conv',help="Convergence limit. Default 1e-5",default='1e-5')
 	parser.add_option('',"--kdaw",dest='kdaw',help="Dimensionality augmentation weight (Kappa). Default 0. -1 for low-dimensional ICA",default=0.)
 	parser.add_option('',"--rdaw",dest='rdaw',help="Dimensionality augmentation weight (Rho). Default 0. -1 for low-dimensional ICA",default=0.)
-	parser.add_option('',"--simpel",dest='simpel',help="Kappa/Rho threshold from simple elbow detection. Good for low tSNR.",action='store_true',default=False)
-	parser.add_option('',"--slign",dest='slign',help="Slices to ignore. 0-indexed. ex: --slign=0,1,2. Default none.",default=None)
 	parser.add_option('',"--OC",dest='OC',help="Output optimally combined time series and features",action="store_true",default=False)
 	parser.add_option('',"--fout",dest='fout',help="Output Voxelwise Kappa/Rho Maps",action="store_true",default=False)
 	parser.add_option('',"--label",dest='label',help="Label for output directory.",default=None)
@@ -719,7 +636,6 @@ if __name__=='__main__':
 	print "++ Loading Data"
 	tes = np.fromstring(options.tes,sep=',',dtype=np.float32)
 	ne = tes.shape[0]
-	repave = int(options.repave)
 	catim  = nib.load(options.data)	
 	head   = catim.get_header()
 	head.extensions = []
@@ -727,9 +643,6 @@ if __name__=='__main__':
 	aff = catim.get_affine()
 	catd = cat2echos(catim.get_data(),ne)
 	nx,ny,nz,Ne,nt = catd.shape
-	if options.slign!=None:
-		slign = [int(ss) for ss in options.slign.split(',')]
-		catd[:,:,slign,:,:] = 0
 	mu  = catd.mean(axis=-1)
 	sig  = catd.std(axis=-1)
 	if options.fout: options.fout = aff
@@ -747,7 +660,8 @@ if __name__=='__main__':
 	mask  = makemask(catd)
 
 	print "++ Computing T2* map"
-	t2s   = t2smap(catd,mask,tes) 
+	t2s,s0   = t2smap(catd,mask,tes) 
+	niwrite(s0,aff,'s0v.nii')
 	niwrite(t2s,aff,'t2sv.nii')
 	
 	if options.mixm == None:
@@ -755,40 +669,8 @@ if __name__=='__main__':
 		import mdp
 		nc,dd = tedpca(options.ste)
 		comptable,mmix,smaps,betas = tedica(dd,cost=options.initcost)
+		acc,rej,midk = selcomps(comptable)
 		np.savetxt('meica_mix.1D',mmix)
-		if repave>1:
-			print "Doing repeated average ME-ICA"
-			mean_hik_ts,mean_other_ts = split_ts(catd[:,:,:,options.e2d-1,:],comptable,mmix)
-			for ii in range(repave-1):
-				comptable,mmix,smaps,betas = tedica(dd,cost=options.initcost)
-				tmp_hik_ts,tmp_other_ts = split_ts(catd[:,:,:,options.e2d-1,:],comptable,mmix)
-				mean_hik_ts+=tmp_hik_ts
-				mean_other_ts+=tmp_other_ts
-			mean_hik_ts/=repave
-			mean_other_ts/=repave
-			#import pdb
-			#pdb.set_trace()
-			niwrite(mean_hik_ts,aff,'hik_ts_e%i_mean%i.nii' % (int(options.e2d),int(options.repave)))
-			niwrite(mean_other_ts,aff,'other_ts_e%i_mean%i.nii' % (int(options.e2d),int(options.repave)))
-		if options.multicost != "":
-			incosts = options.multicost.split(',')
-			print "Doing multi-cost average ME-ICA"
-			mc_comptable = comptable[comptable[:,1].argsort()[::-1],1]
-			mean_hik_ts,mean_other_ts = split_ts(catd[:,:,:,options.e2d-1,:],comptable,mmix)
-			for acost in sorted(set(incosts)-set([options.initcost])):
-				tmp_comptable,mmix,smaps,betas = tedica(dd,cost=acost)
-				mc_comptable = np.vstack([mc_comptable,tmp_comptable[tmp_comptable[:,1].argsort()[::-1],1]])
-				tmp_hik_ts,tmp_other_ts = split_ts(catd[:,:,:,options.e2d-1,:],comptable,mmix)
-				mean_hik_ts+=tmp_hik_ts
-				mean_other_ts+=tmp_other_ts
-			mean_hik_ts/=len(incosts)
-			mean_other_ts/=len(incosts)
-			#import ipdb
-			#ipdb.set_trace()
-			mc_comptable = mc_comptable.T
-			writemcct(mc_comptable,[options.initcost]+incosts)
-			niwrite(mean_hik_ts,aff,'hik_ts_e%i_multicost.nii' % (int(options.e2d)))
-			niwrite(mean_other_ts,aff,'other_ts_e%i_multicost.nii' % (int(options.e2d)))
 		del dd
 	else:
 		mmix = np.loadtxt(options.mixm)
@@ -797,6 +679,36 @@ if __name__=='__main__':
 		betas = get_coeffs(catim.get_data(),np.tile(mask,(1,1,Ne)),mmix)
 		betas = cat2echos(betas,Ne)
 		comptable = fitmodels(betas,t2s,mu,eimum,tes,sig=sig,fout=options.fout,pow=2)
+		acc,rej,midk = selcomps(comptable)
+        if options.dmix!='':
+            dndata = np.dot(betas[:,:,:,:,acc],(mmix[:,acc].T))
+            dndata = uncat2echos(dndata,Ne)
+            dmix = np.atleast_2d(np.loadtxt(options.dmix))
+            if np.min(dmix.shape)==1 and dmix.shape[1]!=1: dmix = dmix.T
+            dbetas = get_coeffs(dndata,np.tile(mask,(1,1,Ne)),dmix,add_const=True)
+            dbetas = cat2echos(dbetas,Ne)
+            
+            #import ipdb;ipdb.set_trace()
+            dcomptable = fitmodels(dbetas[:,:,:,0:,:],t2s,mu[:,:,:,0:],eimum,tes[0:],sig=sig[:,:,:,0:],fout=options.fout,pow=2)
+            writect(dcomptable,'comp_table_dmix.txt')
+            print "++ Writing design matrix component table"
+            ks = dcomptable[:,1]
+            svars = dcomptable[:,3:5].sum(1)*100.
+            dacc = dcomptable[ks>100,0].tolist()
+            
+            rhos = dcomptable[dacc,2].copy()
+            rhos.sort()
+            rho_thr = rhos[min(getelbow(rhos)+1,rhos.shape[0]-1)]
+            rhos = dcomptable[:,2]
+
+            dacc += dcomptable[andb([ks<=100,ks>np.percentile(ks,66)/2.,svars<100./svars.shape[0]])==3,0].tolist()
+            dacc += dcomptable[andb([ks<=100,rhos<=rho_thr,svars<100./svars.shape[0]])==3,0].tolist()
+            dacc = set(dacc)
+            #import ipdb; ipdb.set_trace()
+            drej = list(set(range(dmix.shape[1])).difference(set(dacc)))
+            open('dmix_accepted.txt','w').write(','.join([str(int(cc)) for cc in sorted(dacc)]))
+            open('dmix_midk.txt','w').write(','.join([str(int(cc)) for cc in sorted(drej)]))
+            
 	
 	print "++ Writing component table"
 	writect(comptable,'comp_table.txt')
