@@ -113,13 +113,16 @@ parser.add_option('-f',"",dest='FWHM',help="ex: -f 3mm  Target dataset smoothnes
 parser.add_option('-a',"",dest='anat',help="ex: -a mprage.nii.gz  Anatomical dataset (optional)",default='')
 parser.add_option('-b',"",dest='basetime',help="ex: -b 10  Time to steady-state equilibration in seconds. Default 0. ",default=0)
 extopts=OptionGroup(parser,"Extended preprocessing options")
+extopts.add_option('',"--t2salign",action="store_true",dest='t2salign',help="T2* weighted affine anatomical coregistration",default=False)
 extopts.add_option('',"--no_skullstrip",action="store_true",dest='no_skullstrip',help="Anatomical is already skullstripped (if -a provided)",default=False)
 extopts.add_option('',"--maskpeels",dest='maskpeels',help="Functional masking factor, increase for more aggressive masking, default 3",default=3)
 extopts.add_option('',"--tlrc",dest='tlrc',help="Normalize to Talairach space, specify base, ex: --tlrc TT_N27+tlrc",default=False)
 extopts.add_option('',"--align_args",dest='align_args',help="Additional arguments for 3dAllineate EPI-anatomical alignment",default='')
+extopts.add_option('',"--align_base",dest='align_base',help="Explicitly specify base dataset for volume registration",default='')
 extopts.add_option('',"--TR",dest='TR',help="The TR. Default read from input datasets",default='')
-extopts.add_option('',"--tpattern",dest='tpattern',help="Slice timing (i.e. alt+z, see 3dTshift --help). Default from header. (N.B. This is important!)",default='')
+extopts.add_option('',"--tpattern",dest='tpattern',help="Slice timing (i.e. alt+z, see 3dTshift -help). Default from header. (N.B. This is important!)",default='')
 extopts.add_option('',"--highpass",dest='highpass',help="Highpass filter in Hz (recommended default 0.0)",default=0.0)
+extopts.add_option('',"--detrend",dest='detrend',help="Polynomial detrend order (i.e. an integer, see 3dDetrend -help)")
 parser.add_option_group(extopts)
 icaopts=OptionGroup(parser,"Extended ICA options (see tedana.py -h")
 icaopts.add_option('',"--daw",dest='daw',help="Dimensionality increase weight. Default 10. For low tSNR data, use -1",default='10')
@@ -257,30 +260,67 @@ sl.append("echo 1 > stage" )
 if isf==osf:
 	for ds in datasets: sl.append("cp %s/%s%s%s%s ./%s%s%s%s" % (startdir,prefix,ds,trailing,isf,prefix,ds,trailing,osf))
 else:
-	for ds in datasets: sl.append("3dcalc -a %s/%s%s%s%s -expr 'a' -prefix ./%s%s%s%s" % (startdir,prefix,ds,trailing,isf,prefix,ds,trailing,osf))
+	for ds in datasets: sl.append("3dcalc -float -a %s/%s%s%s%s -expr 'a' -prefix ./%s%s%s%s" % (startdir,prefix,ds,trailing,isf,prefix,ds,trailing,osf))
 vrAinput = "./%s%s" % (vrbase,osf)
-sl.append("3dvolreg -quintic  -prefix ./%s_vrA%s -base %s[%s] -dfile ./%s_vrA.1D -1Dmatrix_save ./%s_vrmat.aff12.1D %s" % \
-		  (vrbase,osf,vrAinput,basebrik,vrbase,prefix,vrAinput))
+if options.align_base!='':
+	if options.align_base.isdigit():
+		basevol = '%s[%s]' % (vrAinput,options.align_base)
+	else:
+		basevol = options.align_base
+else: 
+	basevol = '%s[%s]' % (vrAinput,basebrik)
+sl.append("3dvolreg -tshift -quintic  -prefix ./%s_vrA%s -base %s -dfile ./%s_vrA.1D -1Dmatrix_save ./%s_vrmat.aff12.1D %s" % \
+		  (vrbase,osf,basevol,vrbase,prefix,vrAinput))
 vrAinput = "./%s_vrA%s" % (vrbase,osf)
 if oblique_mode: 
 	if options.anat!='': sl.append("3dWarp -verb -card2oblique %s[0] -overwrite  -newgrid 1.000000 -prefix ./%s_ob.nii.gz %s/%s | \grep  -A 4 '# mat44 Obliquity Transformation ::'  > %s_obla2e_mat.1D" % (vrAinput,anatprefix,startdir,nsmprage,prefix))
 	else: sl.append("3dWarp -overwrite -prefix %s -deoblique %s" % (vrAinput,vrAinput))
 sl.append("1dcat './%s_vrA.1D[1..6]{%s..$}' > motion.1D " % (vrbase,basebrik))
-sl.append("3dcalc -expr 'a' -a %s[%s] -prefix ./_eBmask%s" % (vrAinput,align_base,osf))
-sl.append("3dAutomask -prefix eBmask%s -peels 3 _eBmask%s" % (osf,osf))
+sl.append("3dcalc -float -expr 'a' -a %s[%s] -prefix ./_eBmask%s" % (vrAinput,align_base,osf))
+sl.append("3dAutomask -prefix eBmask%s -dilate 1 -peels 3 _eBmask%s" % (osf,osf))
 e2dsin = prefix+datasets[0]+trailing
 
 # Calculate affine anatomical warp if anatomical provided, then combine motion correction and coregistration parameters 
 if options.anat!='':
-	if grayweight_ok == 1:
+	if options.t2salign:
+		dss = datasets
+		dss.sort()
+		stackline=""
+		for echo_ii in range(len(dss)):
+			echo = datasets[echo_ii]
+			dsin = 'e'+echo+trailing
+			indata = prefix+echo+trailing+osf
+			stackline+=" %s[%i..%i]" % (indata,int(options.basetime),int(options.basetime)+5)
+		sl.append("3dZcat -prefix basestack.nii.gz %s" % (stackline))
+		sl.append("3dcalc -float -a basestack.nii.gz -expr 'a' -overwrite")
+		sl.append("%s %s -d basestack.nii.gz -e %s" % (sys.executable, '/'.join([meicadir,'meica.libs','t2smap.py']),options.tes))
+		sl.append("3dBrickStat -mask s0v.nii -percentile 98 1 98 s0v.nii > maxs0.1D")
+		sl.append("maxs0=`cat maxs0.1D`; maxs0a=($maxs0); vmax=${maxs0a[1]}; p20=`ccalc ${vmax}*.20`" )
+		sl.append("3dcalc -a s0v.nii -b t2sv.nii -expr \"step(a-${p20})*b\" -prefix t2svm.nii.gz" )
+		sl.append("3dBrickStat -mask t2svm.nii.gz -percentile 98 1 98 t2svm.nii.gz > maxt2svm.1D")
+		sl.append("maxt2svm=`cat maxt2svm.1D`; maxt2svma=($maxt2svm); vmax=${maxt2svma[1]}; p20=`ccalc ${vmax}*.20`" )
+		sl.append("3dcalc -a t2svm.nii.gz -expr \"step(a-${p20})*a\" -overwrite -prefix t2svm.nii.gz" )
+		sl.append("3dSeg -anat t2svm.nii.gz -mask t2svm.nii.gz")
+		sl.append("sc0=`3dBrickStat -mask Segsy/Classes+orig. -mvalue 1 -count Segsy/Classes+orig.`;sc1=`3dBrickStat -mask Segsy/Classes+orig. -mvalue 2 -count Segsy/Classes+orig.`;sc2=`3dBrickStat -mask Segsy/Classes+orig. -mvalue 3 -count Segsy/Classes+orig.`")
+		sl.append("cc=\"$sc0 $sc1 $sc2\"")
+		sl.append("IC=(`tr ' ' '\\n' <<<$cc | cat -n | sort -k2,2nr | head -n1`)")
+		sl.append("mb=$(($IC-1))")
+		sl.append("3dcalc -float -a Segsy/Posterior+orig[${mb}] -expr 'a' -prefix epigraywt.nii.gz")
+		sl.append("3dcalc -float -a Segsy/AnatUB+orig -b Segsy/Classes+orig -expr 'a*step(b)' -prefix eBbase%s" % (osf))
+		sl.append("3dmerge -1clust 4 100 -1erode 80 -1dindex 0 -1tindex 0 -1dilate -overwrite -prefix epigraywt.nii.gz epigraywt.nii.gz")
+		weightvol = "epigraywt%s" % osf
+		weightline = ' -lpc -weight %s -base eBbase%s ' % (weightvol,osf)
+	elif grayweight_ok == 1:
 		sl.append("3dSeg -mask eBmask%s -anat _eBmask%s" % (osf,osf))
-		sl.append("3dcalc -a Segsy/Posterior+orig[1] -expr 'a' -prefix epigraywt%s" % (osf))
-		sl.append("3dcalc -a Segsy/AnatUB+orig -b Segsy/Classes+orig -expr 'a*step(b)' -prefix eBbase%s" % (osf))
+		sl.append("3dcalc -float -a Segsy/Posterior+orig[2] -expr 'a' -prefix epigraywt%s" % (osf))
+		sl.append("3dcalc -float -a Segsy/AnatUB+orig -b Segsy/Classes+orig -expr 'a*step(b)' -prefix eBbase%s" % (osf))
+		weightvol = "epigraywt%s" % osf
 		weightline = ' -lpc -weight epigraywt%s -base eBbase%s ' % (osf,osf)
 	elif grayweight_ok == 2:
-		sl.append("3dcalc -overwrite -prefix eBmask%s -a eBmask%s -b _eBmask%s -expr 'a*b'" % (osf,osf,osf))
+		sl.append("3dcalc -float -overwrite -prefix eBmask%s -a eBmask%s -b _eBmask%s -expr 'a*b'" % (osf,osf,osf))
 		sl.append("fast -t 2 -n 3 -H 0.1 -I 4 -l 20.0 -b -o eBmask eBmask%s" % (osf)) 
-		sl.append("3dcalc -a eBmask%s -b eBmask_bias%s -expr 'a/b' -prefix eBbase%s" % ( osf, osf, osf))
+		sl.append("3dcalc -float -a eBmask%s -b eBmask_bias%s -expr 'a/b' -prefix eBbase%s" % ( osf, osf, osf))
+		weightvol = "eBmask_pve_0.nii.gz"		
 		weightline = ' -lpc -weight eBmask_pve_0.nii.gz -base eBbase%s ' % (osf)
 	else: weightline = ' -lpc+ZZ -automask -autoweight -base _eBmask%s ' % (osf)
 	sl.append("cp %s/%s* ." % (startdir,nsmprage))	
@@ -289,7 +329,7 @@ if options.anat!='':
 		sl.append("afnibinloc=`which 3dSkullStrip`")
 		sl.append("templateloc=${afnibinloc%/*}")
 		atnsmprage = "%s_at.nii" % (dsprefix(nsmprage))
-		if not dssuffix(nsmprage).__contains__('nii'): sl.append("3dcalc -a %s -expr 'a' -prefix %s.nii.gz" % (nsmprage,dsprefix(nsmprage)))
+		if not dssuffix(nsmprage).__contains__('nii'): sl.append("3dcalc -float -a %s -expr 'a' -prefix %s.nii.gz" % (nsmprage,dsprefix(nsmprage)))
 		sl.append("if [ ! -e %s ]; then \@auto_tlrc -no_ss -base ${templateloc}/%s -input %s.nii.gz -suffix _at; fi " % (atnsmprage,options.tlrc,dsprefix(nsmprage)))
 		sl.append("3dcopy %s %s" % (atnsmprage,dsprefix(atnsmprage)))
 		sl.append("3drefit -view orig %s+tlrc " % dsprefix(atnsmprage) )
@@ -303,7 +343,7 @@ if options.anat!='':
 	else: align_args=" -maxrot 20 -maxshf 20 -parfix 7 1  -parang 9 0.83 1.0 "
 	if oblique_mode: alnsmprage = "./%s_ob.nii.gz" % (anatprefix)
 	else: alnsmprage = "%s/%s" % (startdir,nsmprage)
-	sl.append("3dAllineate -weight_frac 1.0 -VERB -warp aff %s -source_automask+10 -cmass -master SOURCE -source %s -prefix ./%s_al -1Dmatrix_save %s_al_mat %s" % (weightline,alnsmprage, anatprefix,anatprefix,align_args))
+	sl.append("3dAllineate -weight_frac 1.0 -VERB -warp aff %s -source_automask -cmass -master SOURCE -source %s -prefix ./%s_al -1Dmatrix_save %s_al_mat %s" % (weightline,alnsmprage, anatprefix,anatprefix,align_args))
 	if options.tlrc: tlrc_opt = "%s::WARP_DATA -I" % (atnsmprage)
 	else: tlrc_opt = ""
 	if oblique_mode: oblique_opt = "%s_obla2e_mat.1D" % prefix
@@ -324,7 +364,7 @@ for echo_ii in range(len(datasets)):
 		tpat_opt = ' -tpattern %s ' % options.tpattern
 	else:
 		tpat_opt = ''
-	sl.append("3dTshift -heptic %s -prefix ./%s_ts+orig %s%s" % (tpat_opt,dsin,indata,osf) )
+	sl.append("3dTshift -slice 0 -heptic %s -prefix ./%s_ts+orig %s%s" % (tpat_opt,dsin,indata,osf) )
 	
 	if oblique_mode and options.anat=="":
 		sl.append("3dWarp -overwrite -deoblique -prefix ./%s_ts+orig ./%s_ts+orig" % (dsin,dsin))
@@ -335,27 +375,28 @@ for echo_ii in range(len(datasets)):
 		if zeropad_opts!="" : sl.append("3dZeropad %s -prefix _eBvrmask.nii.gz %s_ts+orig[%s]" % (zeropad_opts,dsin,basebrik))
 		sl.append("3dAllineate -overwrite -final %s -%s -float -1Dmatrix_apply %s_wmat.aff12.1D -base _eBvrmask.nii.gz -input _eBvrmask.nii.gz -prefix ./_eBvrmask.nii.gz" % \
 			(align_interp,align_interp,prefix))
-		sl.append("3dAutomask -peels %s -overwrite -prefix eBvrmask%s _eBvrmask%s" % (str(options.maskpeels),osf,osf))
+		sl.append("3dAutomask -dilate 1 -peels %s -overwrite -prefix eBvrmask%s _eBvrmask%s" % (str(options.maskpeels),osf,osf))
 		sl.append("3dBrickStat -mask eBvrmask.nii.gz -percentile 50 1 50  _eBvrmask.nii.gz > gms.1D" )
 		if options.anat!='':
 			sl.append("3dresample -overwrite -rmode NN -dxyz `3dinfo -ad3 eBvrmask.nii.gz` -inset eBvrmask.nii.gz -prefix eBvrmask.nii.gz -master %s" % (abmprage))
 		else:
 			sl.append("3dAutobox -overwrite -prefix eBvrmask%s eBvrmask%s" % (osf,osf) )
-		sl.append("3dcalc -a eBvrmask.nii.gz -expr 'notzero(a)' -overwrite -prefix eBvrmask.nii.gz")
+		sl.append("3dcalc -float -a eBvrmask.nii.gz -expr 'notzero(a)' -overwrite -prefix eBvrmask.nii.gz")
 	
 	sl.append("3dAllineate -final %s -%s -float -1Dmatrix_apply %s_wmat.aff12.1D -base eBvrmask%s -input  %s_ts+orig -prefix ./%s_vr%s" % \
 		(align_interp,align_interp,prefix,osf,dsin,dsin,osf))
 	
 	if options.FWHM=='0mm': 
-		sl.append("3dcalc -overwrite -a eBvrmask.nii.gz -b ./%s_vr%s[%i..$] -expr 'step(a)*b' -prefix ./%s_sm%s " % (dsin,osf,basebrik,dsin,osf))
+		sl.append("3dcalc -float -overwrite -a eBvrmask.nii.gz -b ./%s_vr%s[%i..$] -expr 'step(a)*b' -prefix ./%s_sm%s " % (dsin,osf,basebrik,dsin,osf))
 	else: 
 		sl.append("3dBlurInMask -fwhm %s -mask eBvrmask%s -prefix ./%s_sm%s ./%s_vr%s[%i..$]" % (options.FWHM,osf,dsin,osf,dsin,osf,basebrik))
 	sl.append("gms=`cat gms.1D`; gmsa=($gms); p50=${gmsa[1]}")
-	sl.append("3dcalc -overwrite -a ./%s_sm%s -expr \"a*10000/${p50}\" -prefix ./%s_sm%s" % (dsin,osf,dsin,osf))
+	sl.append("3dcalc -float -overwrite -a ./%s_sm%s -expr \"a*10000/${p50}\" -prefix ./%s_sm%s" % (dsin,osf,dsin,osf))
 	sl.append("3dTstat -prefix ./%s_mean%s ./%s_sm%s" % (dsin,osf,dsin,osf))
-	if options.highpass!=0.0: sl.append("3dBandpass -prefix ./%s_in%s %f 99 ./%s_sm%s " % (dsin,osf,float(options.highpass),dsin,osf) )
+	if options.detrend: sl.append("3dDetrend -polort %s -overwrite -prefix ./%s_sm%s ./%s_sm%s " % (options.detrend,dsin,osf,dsin,osf) )
+	if options.highpass: sl.append("3dBandpass -prefix ./%s_in%s %f 99 ./%s_sm%s " % (dsin,osf,float(options.highpass),dsin,osf) )
 	else: sl.append("mv %s_sm%s %s_in%s" % (dsin,osf,dsin,osf))
-	sl.append("3dcalc -overwrite -a ./%s_in%s -b ./%s_mean%s -expr 'a+b' -prefix ./%s_in%s" % (dsin,osf,dsin,osf,dsin,osf))
+	sl.append("3dcalc -float -overwrite -a ./%s_in%s -b ./%s_mean%s -expr 'a+b' -prefix ./%s_in%s" % (dsin,osf,dsin,osf,dsin,osf))
 	sl.append("3dTstat -stdev -prefix ./%s_std%s ./%s_in%s" % (dsin,osf,dsin,osf))
 	if options.test_proc: sl.append("exit")
 	if not (options.test_proc or options.keep_int): sl.append("rm -f %s_ts+orig* %s_vr%s %s_sm%s" % (dsin,dsin,osf,dsin,osf))
@@ -375,9 +416,8 @@ else:
 	for echo in ica_datasets: 
 		dsin ='e'+echo+trailing
 		zcatstring = "%s ./%s_in%s" % (zcatstring,dsin,osf)
-
 	sl.append("3dZcat -overwrite -prefix %s  %s" % (ica_input,zcatstring) )
-	sl.append("3dcalc -overwrite -a %s[0] -expr 'notzero(a)' -prefix %s" % (ica_input,ica_mask))
+	sl.append("3dcalc -float -overwrite -a %s[0] -expr 'notzero(a)' -prefix %s" % (ica_input,ica_mask))
 
 if options.pp_only: tedflag='#'
 else: tedflag = ''
@@ -385,10 +425,11 @@ else: tedflag = ''
 if os.path.exists('%s/meica.libs' % (meicadir)): tedanapath = 'meica.libs/tedana.py'
 else: tedanapath = 'tedana.py'
 sl.append("#\n#TE-Dependence analysis command:")
-sl.append("%s%s %s -e %s  -d %s --sourceTEs=%s --kdaw=%s --rdaw=1 --initcost=%s --finalcost=%s --OC" % (tedflag,sys.executable, '/'.join([meicadir,tedanapath]),options.tes,ica_input,options.sourceTEs,options.daw,options.initcost,options.finalcost))
+sl.append("%s%s %s -e %s  -d %s --sourceTEs=%s --kdaw=%s --rdaw=1 --initcost=%s --finalcost=%s --OC --conv=2.5e-5" % (tedflag,sys.executable, '/'.join([meicadir,tedanapath]),options.tes,ica_input,options.sourceTEs,options.daw,options.initcost,options.finalcost))
 sl.append("#")
 if options.prefix=='': options.prefix=setname
 sl.append("#Copying results to start directory")
+"""
 sl.append("%scp TED/ts_OC.nii %s/%s_tsoc.nii" % (tedflag,startdir,options.prefix))
 sl.append("%scp TED/hik_ts_OC.nii %s/%s_medn.nii" % (tedflag,startdir,options.prefix))
 sl.append("%scp TED/betas_hik_OC.nii %s/%s_mefc.nii" % (tedflag,startdir,options.prefix))
@@ -405,6 +446,26 @@ sl.append("%s3dNotes -h \'%s (%s)\' %s/%s_mefc.nii" % (tedflag,hist_line,note_li
 note_line = "T2* weighted average of ME time series, produced by ME-ICA v2.0 (r5)"
 sl.append("%s3dNotes -h \'%s (%s)\' %s/%s_tsoc.nii" % (tedflag,hist_line,note_line,startdir,options.prefix))
 sl.append("%sgzip -f %s/%s_medn.nii %s/%s_mefc.nii %s/%s_tsoc.nii" % (tedflag,startdir,options.prefix,startdir,options.prefix,startdir,options.prefix))
+"""
+
+sl.append("%scp TED/ts_OC.nii TED/%s_tsoc.nii" % (tedflag,options.prefix))
+sl.append("%scp TED/hik_ts_OC.nii TED/%s_medn.nii" % (tedflag,options.prefix))
+sl.append("%scp TED/betas_hik_OC.nii TED/%s_mefc.nii" % (tedflag,options.prefix))
+sl.append("%scp TED/comp_table.txt %s/%s_ctab.txt" % (tedflag,startdir,options.prefix))
+hist_line = "%s" % (" ".join(sys.argv).replace('"',r"\""))
+note_line = "Denoised timeseries, produced by ME-ICA v2.0 (r5)"
+sl.append("%s3dNotes -h \'%s (%s)\' TED/%s_medn.nii" % (tedflag,hist_line,note_line,options.prefix))
+note_line = "Denoised ICA coeff. set for seed-based FC analysis, produced by ME-ICA v2.0 (r1)"
+sl.append("%s3dNotes -h \'%s (%s)\' TED/%s_mefc.nii" % (tedflag,hist_line,note_line,options.prefix))
+note_line = "T2* weighted average of ME time series, produced by ME-ICA v2.0 (r5)"
+sl.append("%s3dNotes -h \'%s (%s)\' TED/%s_tsoc.nii" % (tedflag,hist_line,note_line,options.prefix))
+if options.anat!='' and options.tlrc!=False:
+	sl.append("%snifti_tool -mod_hdr -mod_field sform_code 2 -mod_field qform_code 2 -infiles TED/%s_tsoc.nii -overwrite" % (tedflag,options.prefix))
+	sl.append("%snifti_tool -mod_hdr -mod_field sform_code 2 -mod_field qform_code 2 -infiles TED/%s_medn.nii -overwrite" % (tedflag,options.prefix))
+	sl.append("%snifti_tool -mod_hdr -mod_field sform_code 2 -mod_field qform_code 2 -infiles TED/%s_mefc.nii -overwrite" % (tedflag,options.prefix))
+sl.append("%sgzip -f TED/%s_medn.nii TED/%s_mefc.nii TED/%s_tsoc.nii" % (tedflag,options.prefix,options.prefix,options.prefix))
+sl.append("%smv TED/%s_medn.nii.gz TED/%s_mefc.nii.gz TED/%s_tsoc.nii.gz %s" % (tedflag,options.prefix,options.prefix,options.prefix,startdir))
+
 
 #Write the preproc script and execute it
 ofh = open('_meica_%s.sh' % setname ,'w')
