@@ -27,6 +27,7 @@
 #include <mrilib.h>    
 #include <rsfc.h>    
 #include <3ddata.h>    
+#include "DoTrackit.h"
 
 #define DEP (1)              // search rad of defining ROIs
 #define BASE_DVAL (-1)       // intermed values for ROI-finding
@@ -206,7 +207,7 @@ int main(int argc, char *argv[]) {
 	// ****************************************************************
 	// ****************************************************************
 
-	INFO_message("version: NU");
+	//INFO_message("version: NU");
 	Dim = (int *)calloc(4,sizeof(int));
 
 	// scan args
