@@ -138,9 +138,14 @@ g_history = """
     0.33 Oct 16, 2012 : use new anal_type for init of defaults
          - have 'rest' defaults to differ from 'task' (no 'surface' yet)
          - GUI: added analysis type and domain, and block list
+    0.34 Dec 20, 2012 :
+         - should not have -volreg_tlrc_warp in case of no tlrc block
+         - thanks to P Taylor for noting the problem
+    0.35 Feb 13, 2012: let user know of subj_dir when writing AP command
+    0.36 Apr  5, 2013: added help web link for class handouts
 """
 
-g_version = '0.33 (October 16, 2012)'
+g_version = '0.36 (April 5, 2013)'
 
 # ----------------------------------------------------------------------
 # global definition of default processing blocks
@@ -424,7 +429,10 @@ class AP_Subject(object):
       self.rvars.file_ap   = name # store which file we have written to
       self.rvars.output_ap = 'output.%s' % name # file for command output
 
-      if self.cvars.verb>0: print '++ writing afni_proc.py command to %s'%name
+      if self.cvars.verb>0:
+         if UTIL.is_trivial_dir(self.cvars.subj_dir): pstr = ''
+         else: pstr = '%s/' % self.cvars.subj_dir
+         print '++ writing afni_proc.py command to %s%s' % (pstr, name)
 
       # if requested, make an original copy
       self.LV.retdir = SUBJ.goto_proc_dir(self.cvars.subj_dir)
@@ -948,7 +956,9 @@ class AP_Subject(object):
          self.LV.warp = ''      # not going to tlrc space
          return ''
 
-      self.LV.warp = 'warp'     # unless 'get' and manual
+      # if tlrc block, init to warping (clear if 'get' and 'manual')
+      if 'tlrc' in self.svars.blocks: self.LV.warp = 'warp'
+
       aset = BASE.afni_name(self.svars.anat)
       if self.svars.get_tlrc == 'yes': # require existence and +orig extension
          if not aset.exist():
