@@ -4,8 +4,9 @@
 
 # do we want all of the 
 
-import sys
-import afni_base
+import sys, os
+import afni_base as BASE
+import afni_util as UTIL
 
 # whine about execution as a main program
 if __name__ == '__main__':
@@ -36,6 +37,9 @@ if __name__ == '__main__':
 #   03 Oct 2012 [rickr]:
 #     - add okdash parameter to option instances, to denote whether any
 #       parameters may have dashes
+#
+#   27 Feb 2013 [rickr]:
+#     - added Ziad's apsearch options: -all_opts, -h_find, -h_view
 # ---------------------------------------------------------------------------
 
 # ---------------------------------------------------------------------------
@@ -49,7 +53,7 @@ class OptionList:
         self.show_count = 1     # display option count in show()
         self.verb     = 1       # display option count in show()
 
-    def add_opt(self, name, npar, deflist, acplist=[], req=0, setpar=0,  \
+    def add_opt(self, name, npar, deflist=[], acplist=[], req=0, setpar=0,  \
                 helpstr = "", okdash=1):
         """add an option to the current OptionList
 
@@ -64,7 +68,7 @@ class OptionList:
                 okdash  : flag: if set, params are allowed to start with '-'
         """
         
-        com = afni_base.comopt(name, npar, deflist, acplist, helpstr)
+        com = BASE.comopt(name, npar, deflist, acplist, helpstr)
         com.required = req
         com.okdash = okdash
         if setpar: com.parlist = com.deflist
@@ -109,6 +113,28 @@ class OptionList:
                 olist.append(com)
         return olist
 
+    def have_yes_opt(self, name, default=0, nth=1):
+        """return whether such an option exists and param[0] looks like 'yes'
+
+           default : default value to return if the option does not exist
+           nth     : parameter for matching 'find_opt'
+        """
+        opt = self.find_opt(name, nth=nth)
+        if opt == None: return default
+        if opt_is_yes(opt): return 1
+        return 0
+
+    def have_no_opt(self, name, default=0, nth=1):
+        """return whether such an option exists and param[0] looks like 'no'
+
+           default : default value to return if the option does not exist
+           nth : parameter for matching 'find_opt'
+        """
+        opt = self.find_opt(name, nth=nth)
+        if opt == None: return defauldefault
+        if opt_is_yes(opt): return 1
+        return 0
+
     def count_opt(self, name):
         """return number of comopts where name=name"""
         count = 0
@@ -126,18 +152,18 @@ class OptionList:
                     del self.olist[index]
                     return 1
 
-    def get_string_opt(self, opt_name=None, opt=None):
+    def get_string_opt(self, opt_name=None, opt=None, default=None):
         """return the option parameter string and err
            (if opt is passed, we don't need to find it)
            err = 0 on success, 1 on failure"""
 
         if opt == None: opt = self.find_opt(opt_name)
-        if not opt or not opt.parlist: return None, 0
+        if not opt or not opt.parlist: return default, 0
         if not opt_name: opt_name = opt.name
         if len(opt.parlist) != 1:
             print "** expecting 1 parmeter for option '%s', have: %s" % \
                   (opt_name, opt.parlist)
-            return None, 1
+            return default, 1
         return opt.parlist[0], 0
 
     def get_string_list(self, opt_name=None, opt=None):
@@ -213,7 +239,15 @@ class OptionList:
 
     # rcr - improve this garbage
     def check_special_opts(self, argv):
-        """process known '-optlist_* options', nuking them from list"""
+        """process known '-optlist_* options' and other global_opts,
+           nuking them from argv
+
+           some options are terminal
+        """
+
+        # global options (some take a parameter)
+        global_opts = [ '-optlist_verbose', '-optlist_no_show_count',
+                        '-all_opts', '-h_find', '-h_view' ]
 
         alen = len(argv)
 
@@ -228,6 +262,36 @@ class OptionList:
             argv[ind:ind+1] = []
             if self.verb>1: print '++ optlist: clearing show_count'
 
+        # terminal options (all end in exit)
+        if '-all_opts' in argv:
+            oname = '-all_opts'
+            ind = argv.index(oname)
+            prog = os.path.basename(argv[0])
+            self.show(verb=1)
+            sys.exit(0)
+
+        if '-h_find' in argv:
+            oname = '-h_find'
+            ind = argv.index(oname)
+            prog = os.path.basename(argv[0])
+            if ind == alen-1:
+               print '** global opt %s needs %s option as parameter' \
+                     % (oname, prog)
+               sys.exit(1)
+            cmd = 'apsearch -phelp %s -word %s' % (prog, argv[ind+1])
+            if self.verb>1: print '++ optlist: applying %s via: %s'%(oname,cmd)
+            BASE.simple_shell_exec(cmd)
+            sys.exit(0)
+
+        if '-h_view' in argv:
+            oname = '-h_view'
+            ind = argv.index(oname)
+            prog = os.path.basename(argv[0])
+            cmd = 'apsearch -view_prog_help %s' % prog
+            if self.verb>1: print '++ optlist: applying %s via: %s'%(oname,cmd)
+            BASE.simple_shell_exec(cmd)
+            sys.exit(0)
+
         if self.verb > 1:
             print '-- argv: orig len %d, new len %d' % (alen,len(argv))
 
@@ -279,7 +343,7 @@ def read_options(argv, oplist, verb = -1):
             if verb > 3: print "-d remaining args: %s" % argv[ac:-1]
 
             # create new return option
-            newopt = afni_base.comopt(com.name, com.n_exp, com.deflist)
+            newopt = BASE.comopt(com.name, com.n_exp, com.deflist)
             newopt.i_name = ac          # current index into argv
             newopt.acceptlist = com.acceptlist
             newopt.required = com.required 
@@ -355,7 +419,7 @@ def read_options(argv, oplist, verb = -1):
                 return None
 
             # insert remaining args as trailers
-            newopt = afni_base.comopt('trailers', -1, [])
+            newopt = BASE.comopt('trailers', -1, [])
             newopt.n_found = alen - ac
             newopt.parlist = argv[ac:]
             if verb > 2: print "-- found trailing args: %s" % newopt.parlist
@@ -372,7 +436,7 @@ def read_options(argv, oplist, verb = -1):
                 print "** error: missing option %s" % co.name
                 return None
             elif len(co.deflist) > 0:  # use it
-                newopt = afni_base.comopt(co.name, len(co.deflist), co.deflist)
+                newopt = BASE.comopt(co.name, len(co.deflist), co.deflist)
                 newopt.parlist = newopt.deflist
                 # leave n_found at -1, so calling function knows
                 OL.olist.append(newopt) # insert newopt into our return list
@@ -392,7 +456,8 @@ def opt_is_yes(opt):
     rv = 0
     try:
         val = opt.parlist[0]
-        if val == 'yes' or val == 'Yes' or val == 'YES': rv = 1
+        if val == 'yes' or val == 'Yes' or val == 'YES' \
+                        or val == 'Y'   or val == 'y': rv = 1
     except: pass
 
     return rv
@@ -405,7 +470,8 @@ def opt_is_no(opt):
     rv = 0
     try:
         val = opt.parlist[0]
-        if val == 'no' or val == 'No' or val == 'NO': rv = 1
+        if val == 'no' or val == 'No' or val == 'NO' \
+                       or val == 'N'  or val == 'n': rv = 1
     except: pass
 
     return rv
