@@ -130,9 +130,12 @@ static char g_history[] =
  " 3.8  June 19, 2008   - removing printing of pointers in disp_ functions\n"
  " 3.9  Oct 27, 2010    - added -show_bad_char and -show_bad_all\n"
  " 3.10 Oct 18, 2012    - option -test is same as -show_bad_all\n"
+ " 3.11 Feb 11, 2013    - added recent options to help\n"
+ " 3.12 Mar 07, 2013    - applied -prefix with -show_bad_backslash\n"
+ " 3.13 Jul 09, 2013    - added a little more info for locating bad chars\n"
  "----------------------------------------------------------------------\n";
 
-#define VERSION         "3.10 (October 18, 2012)"
+#define VERSION         "3.13 (July 9, 2013)"
 
 
 /* ----------------------------------------------------------------------
@@ -283,6 +286,8 @@ process_script( char * filename, param_t * p )
 
 /*------------------------------------------------------------
  * Scan file for: '\\' then whitespace then '\n'
+ *
+ * If prefix is set, write to a new file.
  *------------------------------------------------------------*/
 int
 scr_show_bad_bs( char * filename, param_t * p )
@@ -293,28 +298,62 @@ scr_show_bad_bs( char * filename, param_t * p )
     int           count, cur, bcount = 0, bad = 0;
     int           lnum = 1;
 
+    FILE        * outfp = NULL; /* for writing "corrected" file */
+    int           bstart, bc;   /* 'bad' fixing vars            */ 
+
     if( read_file( filename, &fdata, &flen ) < 0 ) return -1;
 
     if( p->debug ) fprintf(stderr,"-- show_bad_backslash: file %s ...\n",
                            filename);
 
+    /* maybe try to fix any errors */
+    if ( p->prefix ) {
+       if( ! p->overwrite && file_exists(p->prefix) ){
+          fprintf(stderr,"** output file '%s' already exists\n",p->prefix);
+          return 1;
+       }
+
+       outfp = fopen(p->prefix, "w");
+       if( !outfp ) {
+          fprintf(stderr,"** failed to open '%s' for writing \n",p->prefix);
+          return 1;
+       }
+
+       if( p->debug )
+          fprintf(stderr, "-- will fix any backslash errors in %s",p->prefix);
+    }
+
     line_start = fdata;
     for( count = 0; count < flen; /* in loop */ )
     {
         /* note beginning of line (it's the next char) */
         if( fdata[count] == '\n' ){  line_start = fdata+count+1;  lnum++; }
 
-        if( fdata[count] != '\\' ){ count++; continue; }
+        if( outfp ) fputc(fdata[count], outfp); /* regardless, char is okay */
+
+        if( fdata[count] != '\\' ){
+           count++;
+           continue;
+        }
 
         /* found a '\\' char, count it and look beyond */
         bcount++; count++;
 
+        /* note first char after '\\', and do not write out corrected
+           file, until we know the line is okay */
+        bstart = count;
+
         /* skip any whitespace */
         cur = count;
         while( fdata[count] != '\n' && isspace(fdata[count]) ) count++;
 
-        if( count == cur || fdata[count] != '\n' )  /* we're okay */
+        if( count == cur || fdata[count] != '\n' ) { /* we're okay */
+            /* if correcting, write all current text out */
+            if( outfp ) {
+               for( bc=bstart; bc < count; bc++ ) fputc(fdata[bc], outfp);
+            }
             continue;
+        }
 
         /* this line is bad, and we're looking at '\n' */
         if( !p->quiet )
@@ -325,10 +364,18 @@ scr_show_bad_bs( char * filename, param_t * p )
                 putchar(*cp);
         }
 
+        /* in fixed (either, really) case, the '\n' write is in next loop */
+
         bad++;
     }
 
-    if(p->debug > 0) fprintf(stderr,"file %s: %d bad lines\n",filename,bad);
+    if(p->debug) fprintf(stderr,"file %s: %d bad lines\n", filename,bad);
+    if(!p->quiet && outfp)
+        fprintf(stderr,"   --> FIXED file written to %s\n", p->prefix);
+
+    /* and close any output file pointer */
+    if( outfp ) fclose(outfp);
+
     if(bad > 255) bad = 255;  /* limit on exit status */
 
     return bad;
@@ -344,7 +391,7 @@ scr_show_bad_ch( char * filename, param_t * p )
     static char * fdata = NULL;
     static int    flen  = 0;
     char        * cp;
-    int           length, count, bad = 0, bad_loc=-1;
+    int           length, lineno, count, bad = 0, bad_loc=-1, bad_line=-1;
 
     if( p->debug ) fprintf(stderr,"-- show_bad_chars: file %s ...\n",
                            filename);
@@ -353,6 +400,7 @@ scr_show_bad_ch( char * filename, param_t * p )
 
     if( p->debug ) fprintf(stderr,"file length = %d\n", length);
 
+    lineno = 1;
     for( cp = fdata, count = 0; count < length; count++ )
     {
         if( !isprint(cp[count]) && !isspace(cp[count]) )
@@ -363,15 +411,22 @@ scr_show_bad_ch( char * filename, param_t * p )
                 if( !bad ) fputs("bad chars", stderr);
                 fprintf(stderr," : %d (0x%0x)",cp[count],0xff & cp[count]);
             }
-            if( bad_loc < 0 ) bad_loc = count;
+            if( bad_loc < 0 ) {
+                bad_loc = count;
+                bad_line = lineno;
+            }
             bad++;
         }
+        if( cp[count] == '\n' ) lineno++;
     }
 
     if( bad && p->debug ) putc('\n', stderr);
-    printf("%s has %d bad characters", filename, bad);
-    if ( bad ) printf(", starting at position %d\n", bad_loc);
-    else       putchar('\n');
+    printf("%s has %d bad characters\n", filename, bad);
+    if ( bad ) {
+        printf("  -- starting at line %d, position %d\n", bad_line, bad_loc);
+        if( bad_loc > 50 )
+           printf("  -- bad chars follow: '%.50s'\n",fdata+(bad_loc-50));
+    } else putchar('\n');
     return 0;
 }
 
@@ -1030,7 +1085,7 @@ set_params( param_t * p, int argc, char * argv[] )
 
     if ( argc < 2 )
     {
-        usage( argv[0], USE_SHORT );
+        usage( argv[0], USE_LONG );
         return -1;
     }
 
@@ -1594,6 +1649,11 @@ help_full( char * prog )
         "\n"
         "   ----- script file checking examples -----\n"
         "\n"
+        "   0. check for any script issues (Unix, backslashes, chars)\n"
+        "      (-test is the same as -show_bad_all)\n"
+        "\n"
+        "      %s -test -infiles my_scripts_*.txt\n"
+        "\n"
         "   1. in each file, check whether it is a UNIX file type\n"
         "\n"
         "      %s -show_file_type -infiles my_scripts_*.txt\n"
@@ -1602,6 +1662,10 @@ help_full( char * prog )
         "\n"
         "      %s -show_bad_backslash -infiles my_scripts_*.txt\n"
         "\n"
+        "   3. in ONE file, correct spaces after trailing backslashes '\\'\n"
+        "\n"
+        "      %s -show_bad_backslash -infile scripts.txt -prefix s.fixed.txt\n"
+        "\n"
         "   ----- character modification examples -----\n"
         "\n"
         "   1. in each file, change the 8 characters at 2515 to 'hi there':\n"
@@ -1690,23 +1754,50 @@ help_full( char * prog )
         "      -mod_ana_hdr     : modify ANALYZE headers\n"
         "      -mod_field       : specify a field and value(s) to modify\n"
         "\n"
-        "      -prefix          : specify and output filename\n"
+        "      -prefix          : specify an output filename\n"
         "      -overwrite       : specify to overwrite the input file(s)\n"
         "\n"
         "  script file options:\n"
         "\n"
+        "      -show_bad_all : show lines with whitespace after '\\'\n"
+        "\n"
+        "          This is meant to find problems in script files where the\n"
+        "          script programmer has spaces or tabs after a final '\\'\n"
+        "          on the line.  That would break the line continuation.\n"
+        "\n"
+        "          The -test option is a shorthand version of this one.\n"
+        "\n"
         "      -show_bad_backslash : show lines with whitespace after '\\'\n"
         "\n"
         "          This is meant to find problems in script files where the\n"
         "          script programmer has spaces or tabs after a final '\\'\n"
         "          on the line.  That would break the line continuation.\n"
         "\n"
+        "          ** If the -prefix option is specified, whitespace after\n"
+        "             backslashes will be removed in the given output file.\n"
+        "\n"
+        "             This can also be used in conjunction with -overwrite.\n"
+        "\n"
+        "          See also -prefix and -overwrite.\n"
+        "\n"
+        "      -show_bad_char   : show any non-printable characters'\\'\n"
+        "\n"
+        "          Sometimes non-visible-but-detrimental characters appear\n"
+        "          in scripts due to editors or email programs.  This option\n"
+        "          helps to point out their presence to the user.\n"
+        "\n"
+        "          See also -show_bad_all or -test.\n"
+        "\n"
         "      -show_file_type  : print file type of UNIX, Mac or DOS\n"
         "\n"
         "          Shell scripts need to be UNIX type files.  This option\n"
         "          will inform the programmer if there are end of line\n"
         "          characters that define an alternate file type.\n"
         "\n"
+        "      -test  : short for -show_bad_all\n"
+        "\n"
+        "          Check script files for known issues.\n"
+        "\n"
         "  raw ascii options:\n"
         "\n"
         "    -length LENGTH     : specify the number of bytes to print/modify\n"
@@ -1718,7 +1809,7 @@ help_full( char * prog )
         "          each of 3 short integers).\n"
         "\n"
         "       ** Note that if the -length argument is MORE than what is\n"
-        "          needed to write the numbers out, the remaind of the length\n"
+        "          needed to write the numbers out, the remaining length of\n"
         "          bytes will be written with zeros.  If '17' is given for\n"
         "          the length, and 3 short integers are given as data, there \n"
         "          will be 11 bytes of 0 written after the 6 bytes of data.\n"
@@ -1728,7 +1819,7 @@ help_full( char * prog )
         "                       : e.g. -mod_data '2 -17.4 649'\n"
         "                       : e.g. -mod_data \"change to this string\"\n"
         "\n"
-        "          This is the data that will be writting into the modified\n"
+        "          This is the data that will be written into the modified\n"
         "          file.  If the -mod_type is 'str' or 'char', then the\n"
         "          output data will be those characters.  If the -mod_type\n"
         "          is any other (i.e. a binary numerical format), then the\n"
@@ -1766,9 +1857,9 @@ help_full( char * prog )
         "\n"
         "          For any of the others, the list of numbers found in the\n"
         "          -mod_data option will be written in the supplied binary\n"
-        "          format.  LENGTH must be large enough to accomodate this\n"
+        "          format.  LENGTH must be large enough to accommodate this\n"
         "          list.  And if LENGTH is higher, the output will be padded\n"
-        "          with zeros, to fill to the requesed length.\n"
+        "          with zeros, to fill to the requested length.\n"
         "\n"
         "    -offset OFFSET     : use this offset into each file\n"
         "                       : e.g. -offset 100\n"
@@ -1799,8 +1890,8 @@ help_full( char * prog )
         "  - R Reynolds, version: %s, compiled: %s\n"
         "\n",
         prog, prog,
+        prog, prog, prog, prog, prog, prog, prog, prog, prog, prog, prog, prog,
         prog, prog, prog, prog, prog, prog, prog, prog, prog, prog, prog,
-        prog, prog, prog, prog, prog, prog, prog, prog, prog, prog,
         VERSION, __DATE__
         );
 
