@@ -54,66 +54,6 @@ typedef struct {
     char FuncName[MAX_ERRLOG_FUNCNAME];
 } SUMA_ERRLOG;
 
-typedef struct {
-   char *envhelp;
-   char *envname;
-   char *envval;  /* This is the default */
-}ENV_SPEC;
-
-typedef struct {
-   char *name;
-   char *help;
-   char *val;  /* This is the default */
-}HELP_OPT;
-
-
-#define SUMA_MAX_NAME_LENGTH 500   /*!< Maximum number of characters in a filename */
-#define SUMA_MAX_DIR_LENGTH 2000    /*!< Maximum number of characters in a directory name */
-#define SUMA_MAX_FILENAME_LENGTH (SUMA_MAX_NAME_LENGTH+SUMA_MAX_DIR_LENGTH+1)
-#ifndef SUMA_IDCODE_LENGTH
-   #define SUMA_IDCODE_LENGTH 50
-#endif
-
-#define SUMA_VERSION_VECTOR 20060703, 20041229, 20040610, 20040116, \
-                            20040106, -10000 /*!< modify this dude and you must update SUMA_New_Additions_perver 
-                                       in SUMA_help.c. 
-                                       Add to the left of the vector, leave the last value of -10000 untouched
-                                       If you like to think of floating point version numbers,divide by 10000
-                                       This define is stuck here so that non-SUMA DataSet manipulating programs 
-                                       can use it, one hopes.
-                                       Numbering is yyyymmdd */
-
-#define SUMA_EMPTY_ATTR "~"
-#define AFNI_NI_CSS "~"    
-#define AFNI_NI_cSS '~'    /* AFNI's NIML Column String Separator (used to separate strings belonging to different columns of input) 
-                              AFNI takes the niml attribute string and turns it into its internal attribute structure.
-                              AFNI_NI_CSS[0] is replaced by \0 and the string is broken into its per-column string list.
-                              That is not the case for BRICK_STATSYM which is treated as one ';' separated string that gets
-                              separately transformed into BRICK_STATAUX attribute entry in AFNI.
-                              This is somewhat confusing when viewing an AFNI dataset in NIML format because BRICK_STATSYM is of ni_type = "String"
-                              like say BRICK_LABS. However this makes sense in AFNI's format because these strings actually
-                              get transformed to attributes of different types in AFNI's internal format.
-                              SUMA will use the same separator for all attributes of ni_type = "String".
-                              Use Macros SUMA_2_AFNI_NI_PCS and AFNI_2_SUMA_NI_PCS if you need to change between SUMA- and AFNI-per-column-strings  
-                              */
-#define SUMA_NI_CSS ";"    /* SUMA's NIML  Per-Column-String Separator 
-                              (used to separate strings belonging to 
-                              different columns of input)  */
-#define SUMA_NI_cSS ';'
-
-#define SUMA_2_AFNI_NI_PCS(a) {\
-   int m_i = 0; \
-   if ((a)) { while ((a)[m_i]) { if ((a)[m_i] == SUMA_NI_cSS) (a)[m_i] = AFNI_NI_cSS; ++m_i; } }\
-}
-
-#define AFNI_2_SUMA_NI_PCS(a) {\
-   int m_i = 0; \
-   if ((a)) { while ((a)[m_i]) { if ((a)[m_i] == AFNI_NI_cSS) (a)[m_i] = SUMA_NI_cSS; ++m_i; } }\
-}
-
-#define SUMA_Boolean byte
-#define NOPE 0
-#define YUP 1
 
 typedef enum { SUMA_SIDE_ERROR=-1, SUMA_NO_SIDE, SUMA_LR, SUMA_LEFT, SUMA_RIGHT } SUMA_SO_SIDE; 
 
@@ -125,14 +65,6 @@ typedef enum { SUMA_NO_NUM_UNITS = 0,
                SUMA_N_NUMERICAL_UNITS
                } SUMA_NUMERICAL_UNITS;
 
-typedef enum { SUMA_notypeset = -1, 
-               SUMA_byte = NI_BYTE, 
-               SUMA_short = NI_SHORT, 
-               SUMA_int = NI_INT, 
-               SUMA_float = NI_FLOAT32, 
-               SUMA_double = NI_FLOAT64, 
-               SUMA_complex = NI_COMPLEX64,
-               SUMA_string = NI_STRING} SUMA_VARTYPE;
 
 /*! simple vectors */
 typedef struct {
@@ -150,84 +82,7 @@ typedef struct {
    double *v;
 } SUMA_DVEC;
 
-#define SUMA_MX_VEC_MAX_DIMS 50
-typedef struct {
-   SUMA_VARTYPE tp;
-   int N_dims;
-   int N_vals;
-   int dims[SUMA_MX_VEC_MAX_DIMS];
-   int fdfm[SUMA_MX_VEC_MAX_DIMS];
-   void *v;
-   byte *bv;
-   short *sv;
-   int *iv;
-   float *fv;
-   double *dv;
-   complex *cv;
-   byte fdf;
-   matrix *m;
-} SUMA_MX_VEC;
 
-/*! macros to access pointers to elements in type double multiplexed vectors with mxv->fdf = 1;
-  \sa SUMA_NewMxVec*/ 
-#define mxvdp4(mxv,i,j,k,l) ( mxv->dv + ( (int)(i) + (int)(j) * mxv->fdfm[0] + (int)(k) * mxv->fdfm[1] + (int)(l) * mxv->fdfm[2] ) )
-#define mxvdp3(mxv,i,j,k)   ( mxv->dv + ( (int)(i) + (int)(j) * mxv->fdfm[0] + (int)(k) * mxv->fdfm[1]   ) )
-#define mxvdp2(mxv,i,j  )   ( mxv->dv + ( (int)(i) + (int)(j) * mxv->fdfm[0]   ) )
-#define mxvdp1(mxv,i  )     ( mxv->dv + ( (int)(i)   ) )
-/*! macros to access elements in type double multiplexed vectors with mxv->fdf = 1;
-  \sa SUMA_NewMxVec*/ 
-#define mxvd4(mxv,i,j,k,l) ( mxv->dv[( (int)(i) + (int)(j) * mxv->fdfm[0] + (int)(k) * mxv->fdfm[1] + (int)(l) * mxv->fdfm[2] )] )
-#define mxvd3(mxv,i,j,k)   ( mxv->dv[( (int)(i) + (int)(j) * mxv->fdfm[0] + (int)(k) * mxv->fdfm[1]   )] )
-#define mxvd2(mxv,i,j  )   ( mxv->dv[( (int)(i) + (int)(j) * mxv->fdfm[0]   )] )
-#define mxvd1(mxv,i  )     ( mxv->dv[( (int)(i)   )] )
-/*! macros to access elements in type complex multiplexed vectors with mxv->fdf = 1;
-  \sa SUMA_NewMxVec*/ 
-#define mxvc4(mxv,i,j,k,l) ( mxv->cv[( (int)(i) + (int)(j) * mxv->fdfm[0] + (int)(k) * mxv->fdfm[1] + (int)(l) * mxv->fdfm[2] )] )
-#define mxvc3(mxv,i,j,k)   ( mxv->cv[( (int)(i) + (int)(j) * mxv->fdfm[0] + (int)(k) * mxv->fdfm[1]   )] )
-#define mxvc2(mxv,i,j  )   ( mxv->cv[( (int)(i) + (int)(j) * mxv->fdfm[0]   )] )
-#define mxvc1(mxv,i  )     ( mxv->cv[( (int)(i)   )] )
-
-/*! filename and path */
-typedef struct {
-   char *Path;
-   char *FileName;
-}SUMA_FileName;
-
-/*! filename, extension and path */
-typedef struct {
-   char *AbsPath;
-   char *RelPath;
-   char *RelDir;
-   char *Path;
-   char *FileName;
-   char *FileName_NoExt;
-   char *FullName;
-   char *FullName_NoSel;
-   char *Ext;
-   char *Prefix;
-   char *View;
-   char *TypeExt;
-   char *StorageModeName;
-   int   StorageMode;
-   char *NodeSelect;
-   char *ColSelect;
-   char *RowSelect;
-   char *RangeSelect;
-   int only_index;
-   int OnDisk;
-   char *HeadName;
-   char *BrikName;
-   char *NameAsParsed;
-   char *cwdAsParsed;
-}SUMA_PARSED_NAME;
-
-
-/*! string stucture 
-*/
-typedef struct {
-   int N_alloc;  /*!< space allocated for s */
-   char *s; /*!< string s */
-} SUMA_STRING;
 
 typedef enum {
    SUMA_ERROR_DSET_TYPE = -1,
@@ -454,7 +309,7 @@ typedef enum { SUMA_NO_PTR_TYPE,
                SUMA_N_LINKED_PTR_TYPES } SUMA_LINKED_PTR_TYPES;
 
 typedef enum { MAT_UNKNOWN=-2, MAT_NA = -1, MAT_HEEHAW = 0 /* not set */, 
-               MAT_SQUARE = 1, MAT_TRI, MAT_TRI_DIAG, MAT_SPARSE 
+               MAT_FULL = 1, MAT_TRI, MAT_TRI_DIAG, MAT_SPARSE 
               } SUMA_SQ_MATRIX_SHAPES; 
 
 typedef struct { /* Something to hold auxiliary datasets structs */
@@ -926,6 +781,9 @@ typedef struct {
    }  \
 }
 
+/* Edges are the 'nodes' of datasets */
+#define GDSET_MAX_EDGE_INDEX DSET_MAX_NODE_INDEX   
+
 /*!
    \brief Macros to access commonly used colorplane parameters
    DO NOT USE COLP_NODEDEF macro inside a loop where the returned
@@ -1018,6 +876,7 @@ static byte NI_GOT;
    char m_stmp[100]; sprintf(m_stmp,"%f", val);   \
    NI_set_attribute(ngr, name, m_stmp);  \
 }
+
 #define NI_GET_FLOAT(ngr, name, val)  {\
    char *m_s = NI_get_attribute(ngr, name);  \
    if (m_s) { NI_GOT = 1; val = atof(m_s); } else { NI_GOT = 0; val = 0.0; }\
@@ -1057,6 +916,50 @@ static byte NI_GOT;
    } else { NI_GOT = 0; }  \
 }
 
+#define NI_SET_DOUBLE(ngr, name, val)  {\
+   char m_stmp[100]; sprintf(m_stmp,"%f", val);   \
+   NI_set_attribute(ngr, name, m_stmp);  \
+}
+
+#define NI_GET_DOUBLE(ngr, name, val)  {\
+   char *m_s = NI_get_attribute(ngr, name);  \
+   if (m_s) { NI_GOT = 1; val = strtod(m_s,NULL); } else { NI_GOT = 0; val = 0.0; }\
+}
+
+#define NI_SET_DOUBLEv(ngr, name, valv, n) {\
+   char m_stmp[400]; int m_i=0, m_s=0;  m_stmp[0] = '\0';\
+   for (m_i=0; m_i<n && m_s < 350; ++m_i) { \
+      sprintf(m_stmp+m_s, " %f", valv[m_i]);   \
+      m_s = strlen(m_stmp);  \
+      if (m_s >= 350) { SUMA_S_Warn("Too long a vector, might get truncated"); }\
+   }\
+   NI_set_attribute(ngr, name, m_stmp);  \
+}
+
+#define NI_GET_DOUBLEv(ngr, name, valv, n, verb) {\
+   char *m_s = NI_get_attribute(ngr, name);  \
+   int m_nr, m_i; double *m_fv;  \
+   for (m_i=0; m_i<n; ++m_i) valv[m_i] = 0.0;   \
+   if (m_s) {  \
+      NI_GOT = 1; \
+      m_fv = (double *)SUMA_strtol_vec(m_s, n, &m_nr, SUMA_double, NULL); \
+      if (m_fv) {\
+         if (verb) {\
+            if (m_nr < n) { \
+               SUMA_S_Warn("Fewer values in field\nProceeding..."); }  \
+            else if (m_nr > n) { \
+               SUMA_S_Warn("More values in field\nProceeding..."); }  \
+         }  \
+         for (m_i=0; m_i<SUMA_MIN_PAIR(n, m_nr);++m_i) \
+            valv[m_i] = m_fv[m_i];    \
+         SUMA_free(m_fv);  \
+      } else {    \
+         NI_GOT = 1; \
+         if (verb) SUMA_S_Warn("NULL vec, filling with zeros"); \
+      }  \
+   } else { NI_GOT = 0; }  \
+}
+
 #define NI_SET_PTR(ngr, name, val) {   \
    char m_stmp[100]; sprintf(m_stmp,"%p",val);  \
    NI_set_attribute(ngr, name, m_stmp);  \
@@ -1702,7 +1605,6 @@ void *SUMA_LinkToPointer(void *ptr);
 void *SUMA_UnlinkFromPointer(void *ptr);
 int * SUMA_GetNodeDef(SUMA_DSET *dset);
 int SUMA_GetNodeDefColIndex(SUMA_DSET *dset);
-int SUMA_NodeIndex_To_Index(int *NodeIndex, int N_Node, int n);
 int SUMA_FillDsetNelCol (SUMA_DSET *dset, char *col_label,
                      SUMA_COL_TYPE ctp, void *col, 
                      void *col_attr, int stride); 
@@ -1837,17 +1739,6 @@ void * SUMA_OpenDx_Object_Header_Field(char *op, int nchar, const char *attr,
                                        char **op_end);
 SUMA_Boolean SUMA_OpenDx_Object_Data(char *op, int nchar, 
                                      SUMA_OPEN_DX_STRUCT *dx);
-SUMA_MX_VEC *SUMA_FreeMxVec(SUMA_MX_VEC *mxv);
-SUMA_MX_VEC *SUMA_NewMxVec(SUMA_VARTYPE tp, int N_dims, int *dims, 
-                           byte first_dim_first);
-char *SUMA_MxVec_Info (SUMA_MX_VEC *mxv, int detail, char *title);
-void SUMA_ShowMxVec (SUMA_MX_VEC *mxv, int detail, FILE *out, char *title);
-int SUMA_MxVecInit(SUMA_MX_VEC *mxv, void *val);
-int SUMA_NewMxAllocVec(SUMA_MX_VEC *mxv) ;
-SUMA_MX_VEC *SUMA_NewMxNullVec(SUMA_VARTYPE tp, int N_dims, int *dims, 
-                               byte first_dim_first);
-SUMA_MX_VEC *SUMA_VecToMxVec(SUMA_VARTYPE tp, int N_dims, int *dims, 
-                              byte first_dim_first, void *vec);
 int * SUMA_FindNumericDataDsetCols(SUMA_DSET *dset, int *N_icols);
 float * SUMA_DsetCol2FloatFullSortedColumn(  
             SUMA_DSET *dset, int ico, byte **nmaskp, float fillval,
@@ -1901,25 +1792,6 @@ NI_group *SUMA_NI_Cmap_of_Dset(SUMA_DSET *dset);
       SUMA_process_environ(); \
       SUMA_ParseInput_basics_ns (argv, argc);   \
    }
-char * SUMA_to_lower(char *s) ;
-int SUMA_filexists (char *f_name);
-int SUMA_search_file(char **fnamep, char *epath);
-char *SUMA_help_basics();
-char *SUMA_help_cmap();
-char *SUMA_help_talk();
-char *SUMA_help_mask();
-char *SUMA_help_dset();
-int get_Domemtrace(void);
-void set_Domemtrace(int s);
-int get_Doiotrace(void);
-void set_Doiotrace(int s) ;
-int get_IgnoreXforms(void);
-void setIgnoreXforms(int s) ;
-void SUMA_process_environ(void);
-int NoSumaRcFound (void);
-void SUMA_ParseInput_basics_ns (char *argv[], int argc); 
-int SUMA_ParseInput_basics_eng (char *argv[], int argc); 
-void WorkErrLog_ns(void);
 
 #define SUMA_DSET_NAME_CHECK(prefix) { \
    char *NameOut=NULL; SUMA_DSET_FORMAT form=SUMA_NO_DSET_FORMAT; \
@@ -1934,53 +1806,12 @@ void WorkErrLog_ns(void);
    } if (NameOut) SUMA_free(NameOut); \
 }
 
-SUMA_FileName SUMA_StripPath (char *FileName);
 SUMA_DSET_FORMAT SUMA_FormatFromFormString(char *arg);
-SUMA_PARSED_NAME * SUMA_ParseFname (char *FileName, char *cwd);
-SUMA_PARSED_NAME * SUMA_DuplicateParsedName(SUMA_PARSED_NAME *pn);
-SUMA_PARSED_NAME * SUMA_ModifyParsedName (SUMA_PARSED_NAME *pn, 
-                                          char *what, char *val);
-char * SUMA_ModifyName(char *name, char *what, char *val, char *cwd);
-SUMA_PARSED_NAME * SUMA_ParseModifyName(char *name, 
-                                        char *what, char *val, char *cwd);
-char *SUMA_Extension(char *filename, char *ext, SUMA_Boolean Remove);
 SUMA_DSET_FORMAT SUMA_GuessFormatFromExtension(char *Name, char *fallbackname);
 const char *SUMA_ExtensionOfDsetFormat (SUMA_DSET_FORMAT form);
-SUMA_Boolean SUMA_isExtension(char *filename, char *ext);
-char * SUMA_CropExtension(char *filename, char *ext);
-void *SUMA_Free_Parsed_Name(SUMA_PARSED_NAME *Test);
 char *SUMA_OutputDsetFileStatus(char *prefix, char *inname, 
                             SUMA_DSET_FORMAT *oform, 
                             char *pre, char *app, int *exists);
-char *SUMA_FnameGet(char *Fname, char *sel, char *cwd);
-int SUMA_NumStringUnits (char *s, int marktip); 
-int SUMA_strtod(char *n, double *valp);
-int SUMA_StringToNum (char *s, void *vv, int N, int p);
-int SUMA_StringToNumSide (char *s, void *vv, int N, int p, int *sd);
-SUMA_SO_SIDE SUMA_giiStringToNumSide(char *cc);
-int SUMA_isNumString (char *s, void *p);
-int SUMA_CleanNumString (char *s, void *p);
-int SUMA_CleanNumStringSide (char *s, void *p);
-char *SUMA_copy_string(char *buf);
-char * SUMA_replace_string(char *s1, char *s2);
-char *SUMA_copy_quoted( char *s, char *eop, 
-                        char q1, char q2, int deblank,
-                        int withquotes, int *is_closed );
-char *args_in_quotes(char **argv, int *kar, int N_argv, char *opq, 
-                     char *cloq, int clearused);
-char *args_in_niml_quotes(char **argv, int *kar, int N_argv, int clearused);
-char *args_in_simple_quotes(char **argv, int *kar, int N_argv, int clearused);
-char * SUMA_append_string(char *s1, char *s2);
-char * SUMA_append_extension(char *s1, char *s2);
-char * SUMA_append_replace_string(  char *s1, char *s2, 
-                                    char *Spc, int whichTofree);
-char * SUMA_append_replace_num(char *s1, char *form, double num, SUMA_VARTYPE tp, int whichTofree);
-char * SUMA_truncate_string (char *s1, int length);
-char *SUMA_set_string_length(char *buf, char cp, int n);
-SUMA_STRING * SUMA_StringAppend (SUMA_STRING *SS, char *newstring);
-SUMA_STRING * SUMA_StringAppend_va (SUMA_STRING *SS, char *newstring, ... );
-void SUMA_sigfunc(int sig);
-char * SUMA_pad_string(char *buf, char cp, int n, int add2end);
 char * SUMA_GetDsetValInCol(SUMA_DSET *dset, int ind, int ival, double *dval) ;
 char * SUMA_GetValInCol(NI_element *nel, int ind, int ival, double *dval); 
 void **SUMA_Dset2VecArray(SUMA_DSET *dset, 
@@ -2008,22 +1839,6 @@ int SUMA_GetNodeIndex_FromNodeRow_ns(SUMA_DSET *dset, int row, int N_Node);
 int SUMA_GetNodeIndex_FromNodeRow_eng(SUMA_DSET *dset, int row, int N_Node);
 double SUMA_GetDsetNodeValInCol2(SUMA_DSET *dset, int ind, 
                                  int node, int N_Node);
-NI_str_array *SUMA_free_NI_str_array(NI_str_array *nisa);
-NI_str_array *SUMA_NI_str_array(NI_str_array *clss, char *what, char *action); 
-int SUMA_NI_str_array_find( char *targ , NI_str_array *sar , 
-                            int partial, int ci);
-NI_str_array *SUMA_comp_str_2_NI_str_ar(char *s, char *sep);
-void SUMA_Show_NI_str_ar(NI_str_array *nisa, FILE *out);
-char *SUMA_NI_str_ar_2_comp_str (NI_str_array *nisa, char *sep);
-char *SUMA_Get_Sub_String(char *cs, char *sep, int ii);
-SUMA_Boolean SUMA_Set_Sub_String(char **cs, char *sep, int ii, char *str);
-int SUMA_AddColAtt_CompString(NI_element *nel, int col, char *lbl, 
-                              char *sep, int insert_mode);
-int SUMA_Remove_Sub_String(char *cs, char *sep, char *strn);
-NI_str_array * SUMA_NI_decode_string_list( char *ss , char *sep );
-NI_str_array * SUMA_NI_string_vec_to_str_array( char **ss , int nss );
-char  * SUMA_NI_get_ith_string( char *ss , char *sep, int i );
-int  SUMA_NI_find_in_cs_string( char *ss , char *sep, char *str );
 SUMA_VARTYPE SUMA_CTypeName2VarType (char *vt);
 const char *SUMA_VarType2CTypeName (SUMA_VARTYPE vt);
 SUMA_COL_TYPE SUMA_VarType2ColType (char *vt);
@@ -2034,21 +1849,10 @@ void SUMA_swap_4(void *ppp);
 void SUMA_swap_8(void *ppp);
 int SUMA_suck_file( char *fname , char **fbuf );
 char * SUMA_file_suck( char *fname , int *nread );
-void *SUMA_AdvancePastNumbers(char *op, char **opend, SUMA_VARTYPE tp);
-void *SUMA_strtol_vec(char *op, int nvals, int *nread, 
-                      SUMA_VARTYPE vtp, char **opend);
-SUMA_Boolean SUMA_ShowParsedFname(SUMA_PARSED_NAME *pn, FILE *out);
-char *SUMA_EscapeChars(char *s1, char *ca, char *es);
-char *SUMA_ReplaceChars(char *s1, char *ca, char *es);
-char *SUMA_isEnv(char *env, char *sval);
-float SUMA_floatEnv(char *env, float defval);
-ENV_SPEC SUMA_envlistelement(int i);
-char * SUMA_EnvVal(char *env);
-int SUMA_EnvEquals(char *env, char *sval, byte ci, char *sep);
  
-/*********************** END Miscellaneous support functions **************************** */
 
 /******** BEGIN functions for surface structure  ******************** */
+SUMA_SO_SIDE SUMA_giiStringToNumSide(char *cc);
 void SUMA_ShowAfniSurfaceObject(NI_group *aSO, FILE *out,
                               int detail, char *title);
 char *SUMA_AfniSurfaceObject_Info(NI_group *aSO, 
@@ -2079,25 +1883,27 @@ int SUMA_PopulateDsetsFromGICORnel(NI_element *nel, GICOR_setup *giset,
 #define SUMA_CItri_pmax_diag(n) (((n)*((n)+1))/2-1)
 #define SUMA_CItri_pmax(n)      (((n)*((n)-1))/2-1)
 
-SUMA_Boolean SUMA_Dset_to_GDset(SUMA_DSET **dset,  
+SUMA_DSET *SUMA_FloatVec_to_GDSET(float **vec, int vec_num, int vec_len, 
+                                  char *mtype, 
+                                  char **vec_labs, int *ie, int *i0, int *i1);
+SUMA_Boolean SUMA_Dset_to_GDSET(SUMA_DSET **dset, char *mtype,  
                                 int ok_verticalize, int *ie, int *i0, int *i1);
 byte SUMA_CItri_p2ij(int p, int n, int two_n, byte withdiag, int *i, int *j);
 SUMA_Boolean SUMA_GDSET_Set_Aux_matrix_shape(SUMA_DSET *dset);
 byte SUMA_GDSET_SegIndexToPoints(SUMA_DSET *dset, int si, 
                                  int *i1, int *i2, int *row);
 byte SUMA_GDSET_PointsToSegIndex(SUMA_DSET *dset, int i1, int i2, int *si);
+byte SUMA_GDSET_SegRowToPoints(SUMA_DSET *dset, int ri, 
+                                 int *i1, int *i2, int *index);
+byte SUMA_GDSET_PointsToSegRow(SUMA_DSET *dset, int i1, int i2, int *ri);
 SUMA_SQ_MATRIX_SHAPES SUMA_matrix_shape_name_to_matrix_shape(char *name); 
 char * SUMA_matrix_shape_to_matrix_shape_name(SUMA_SQ_MATRIX_SHAPES sq);
-SUMA_Boolean SUMA_binSearch( float *nodeList, float target, int *seg);
-int SUMA_binFind( float *indexList, int N_node, float target);
-SUMA_Boolean SUMA_ibinSearch( int *indexList, int target, int *seg);
-int SUMA_ibinFind( int *indexList, int N_node, int target);
-int *SUMA_reorder(int *y, int *isort, int N_isort);
-double *SUMA_dreorder(double *y, int *isort, int N_isort);
-float *SUMA_freorder(float *y, int *isort, int N_isort);
 int *SUMA_GDSET_GetPointIndexColumn(SUMA_DSET *dset, int *N_vals, NI_element **);
 int SUMA_GDSET_Index_To_NodeIndex(SUMA_DSET *dset, int cinode);
 int SUMA_GDSET_NodeIndex_To_Index(SUMA_DSET *dset, int node);
+int SUMA_GDSET_EdgeIndex_To_Row(SUMA_DSET *dset, int ei);
+int SUMA_GDSET_EdgeRow_To_Index(SUMA_DSET *dset, int ri);
+int SUMA_GDSET_Max_Edge_Index(SUMA_DSET *dset);
 
 
 #endif
